Struct NSEvent

#[repr(C)]
pub struct NSEvent { /* private fields */ }
πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
Available on crate features AppKit and AppKit_NSEvent only.

ImplementationsΒ

SourceΒ

impl NSEvent

pub unsafe fn type(&self) -> NSEventType

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn modifierFlags(&self) -> NSEventModifierFlags

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn timestamp(&self) -> NSTimeInterval

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn window(&self, mtm: MainThreadMarker) -> Option<Id<NSWindow>>

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
Available on crate feature AppKit_NSWindow only.
pub unsafe fn windowNumber(&self) -> NSInteger

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn context(&self) -> Option<Id<NSGraphicsContext>>

πŸ‘ŽDeprecated: This method always returns nil. If you need access to the current drawing context, use [NSGraphicsContext currentContext] inside of a draw operation.
Available on crate feature AppKit_NSGraphicsContext only.
pub unsafe fn clickCount(&self) -> NSInteger

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn buttonNumber(&self) -> NSInteger

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn eventNumber(&self) -> NSInteger

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn pressure(&self) -> c_float

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn locationInWindow(&self) -> NSPoint

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn deltaX(&self) -> CGFloat

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn deltaY(&self) -> CGFloat

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn deltaZ(&self) -> CGFloat

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn hasPreciseScrollingDeltas(&self) -> bool

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn scrollingDeltaX(&self) -> CGFloat

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn scrollingDeltaY(&self) -> CGFloat

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn momentumPhase(&self) -> NSEventPhase

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn isDirectionInvertedFromDevice(&self) -> bool

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn characters(&self) -> Option<Id<NSString>>

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
Available on crate feature Foundation_NSString only.
pub unsafe fn charactersIgnoringModifiers(&self) -> Option<Id<NSString>>

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
Available on crate feature Foundation_NSString only.
pub unsafe fn charactersByApplyingModifiers( &self, modifiers: NSEventModifierFlags, ) -> Option<Id<NSString>>

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
Available on crate feature Foundation_NSString only.
pub unsafe fn isARepeat(&self) -> bool

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn keyCode(&self) -> c_ushort

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn trackingNumber(&self) -> NSInteger

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn userData(&self) -> *mut c_void

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn trackingArea(&self) -> Option<Id<NSTrackingArea>>

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
Available on crate feature AppKit_NSTrackingArea only.
pub unsafe fn subtype(&self) -> NSEventSubtype

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn data1(&self) -> NSInteger

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn data2(&self) -> NSInteger

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn eventRef(&self) -> *mut c_void

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn eventWithEventRef( event_ref: NonNull<c_void>, ) -> Option<Id<NSEvent>>

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn isMouseCoalescingEnabled() -> bool

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn setMouseCoalescingEnabled(mouse_coalescing_enabled: bool)

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn magnification(&self) -> CGFloat

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn deviceID(&self) -> NSUInteger

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn rotation(&self) -> c_float

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn absoluteX(&self) -> NSInteger

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn absoluteY(&self) -> NSInteger

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn absoluteZ(&self) -> NSInteger

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn buttonMask(&self) -> NSEventButtonMask

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn tilt(&self) -> NSPoint

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn tangentialPressure(&self) -> c_float

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn vendorDefined(&self) -> Id<AnyObject>

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn vendorID(&self) -> NSUInteger

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn tabletID(&self) -> NSUInteger

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn pointingDeviceID(&self) -> NSUInteger

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn systemTabletID(&self) -> NSUInteger

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn vendorPointingDeviceType(&self) -> NSUInteger

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn pointingDeviceSerialNumber(&self) -> NSUInteger

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn uniqueID(&self) -> c_ulonglong

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn capabilityMask(&self) -> NSUInteger

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn pointingDeviceType(&self) -> NSPointingDeviceType

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn isEnteringProximity(&self) -> bool

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn touchesMatchingPhase_inView( &self, phase: NSTouchPhase, view: Option<&NSView>, ) -> Id<NSSet<NSTouch>>

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
Available on crate features AppKit_NSTouch and AppKit_NSView and Foundation_NSSet only.
pub unsafe fn allTouches(&self) -> Id<NSSet<NSTouch>>

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
Available on crate features AppKit_NSTouch and Foundation_NSSet only.
pub unsafe fn touchesForView(&self, view: &NSView) -> Id<NSSet<NSTouch>>

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
Available on crate features AppKit_NSTouch and AppKit_NSView and Foundation_NSSet only.
pub unsafe fn coalescedTouchesForTouch( &self, touch: &NSTouch, ) -> Id<NSArray<NSTouch>>

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
Available on crate features AppKit_NSTouch and Foundation_NSArray only.
pub unsafe fn phase(&self) -> NSEventPhase

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn stage(&self) -> NSInteger

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn stageTransition(&self) -> CGFloat

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn associatedEventsMask(&self) -> NSEventMask

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn pressureBehavior(&self) -> NSPressureBehavior

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn isSwipeTrackingFromScrollEventsEnabled() -> bool

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn trackSwipeEventWithOptions_dampenAmountThresholdMin_max_usingHandler( &self, options: NSEventSwipeTrackingOptions, min_dampen_threshold: CGFloat, max_dampen_threshold: CGFloat, tracking_handler: &Block<(CGFloat, NSEventPhase, Bool, NonNull<Bool>), ()>, )

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn startPeriodicEventsAfterDelay_withPeriod( delay: NSTimeInterval, period: NSTimeInterval, )

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn stopPeriodicEvents()

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn mouseEventWithType_location_modifierFlags_timestamp_windowNumber_context_eventNumber_clickCount_pressure( type: NSEventType, location: NSPoint, flags: NSEventModifierFlags, time: NSTimeInterval, w_num: NSInteger, unused_pass_nil: Option<&NSGraphicsContext>, e_num: NSInteger, c_num: NSInteger, pressure: c_float, ) -> Option<Id<NSEvent>>

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
Available on crate feature AppKit_NSGraphicsContext only.
pub unsafe fn keyEventWithType_location_modifierFlags_timestamp_windowNumber_context_characters_charactersIgnoringModifiers_isARepeat_keyCode( type: NSEventType, location: NSPoint, flags: NSEventModifierFlags, time: NSTimeInterval, w_num: NSInteger, unused_pass_nil: Option<&NSGraphicsContext>, keys: &NSString, ukeys: &NSString, flag: bool, code: c_ushort, ) -> Option<Id<NSEvent>>

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
Available on crate features AppKit_NSGraphicsContext and Foundation_NSString only.
pub unsafe fn enterExitEventWithType_location_modifierFlags_timestamp_windowNumber_context_eventNumber_trackingNumber_userData( type: NSEventType, location: NSPoint, flags: NSEventModifierFlags, time: NSTimeInterval, w_num: NSInteger, unused_pass_nil: Option<&NSGraphicsContext>, e_num: NSInteger, t_num: NSInteger, data: *mut c_void, ) -> Option<Id<NSEvent>>

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
Available on crate feature AppKit_NSGraphicsContext only.
pub unsafe fn otherEventWithType_location_modifierFlags_timestamp_windowNumber_context_subtype_data1_data2( type: NSEventType, location: NSPoint, flags: NSEventModifierFlags, time: NSTimeInterval, w_num: NSInteger, unused_pass_nil: Option<&NSGraphicsContext>, subtype: c_short, d1: NSInteger, d2: NSInteger, ) -> Option<Id<NSEvent>>

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
Available on crate feature AppKit_NSGraphicsContext only.
pub unsafe fn mouseLocation() -> NSPoint

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn modifierFlags_class() -> NSEventModifierFlags

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn pressedMouseButtons() -> NSUInteger

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn doubleClickInterval() -> NSTimeInterval

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn keyRepeatDelay() -> NSTimeInterval

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn keyRepeatInterval() -> NSTimeInterval

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn addGlobalMonitorForEventsMatchingMask_handler( mask: NSEventMask, block: &Block<(NonNull<NSEvent>,), ()>, ) -> Option<Id<AnyObject>>

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn addLocalMonitorForEventsMatchingMask_handler( mask: NSEventMask, block: &Block<(NonNull<NSEvent>,), *mut NSEvent>, ) -> Option<Id<AnyObject>>

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn removeMonitor(event_monitor: &AnyObject)

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
SourceΒ

impl NSEvent

Methods declared on superclass NSObject

pub unsafe fn init(this: Allocated<Self>) -> Id<Self>

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit
pub unsafe fn new() -> Id<Self>

πŸ‘ŽDeprecated: icrate::AppKit has been moved to objc2-app-kit

Methods from Deref<Target = NSObject>Β

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Available on crate feature AuthenticationServices only.

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>Β

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

ΒExample

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

πŸ‘ŽDeprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

ΒSafety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut T
where T: Encode,

πŸ‘ŽDeprecated: this is difficult to use correctly, use Ivar::load_mut instead.

Use Ivar::load_mut instead.

ΒSafety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.