#[repr(C)]pub struct NSShadow { /* private fields */ }👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitAvailable on crate features
AppKit and AppKit_NSShadow only.Implementations
Sourceimpl NSShadow
impl NSShadow
pub unsafe fn init(this: Allocated<Self>) -> Id<Self>
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitpub unsafe fn shadowOffset(&self) -> NSSize
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitpub unsafe fn setShadowOffset(&self, shadow_offset: NSSize)
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitpub unsafe fn shadowBlurRadius(&self) -> CGFloat
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitpub unsafe fn setShadowBlurRadius(&self, shadow_blur_radius: CGFloat)
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitpub unsafe fn shadowColor(&self) -> Option<Id<NSColor>>
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitAvailable on crate feature
AppKit_NSColor only.pub unsafe fn setShadowColor(&self, shadow_color: Option<&NSColor>)
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitAvailable on crate feature
AppKit_NSColor only.pub unsafe fn set(&self)
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitMethods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Available on crate feature AuthenticationServices only.
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
AuthenticationServices only.Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.