#[repr(C)]pub struct NSTextAttachment { /* private fields */ }👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitAvailable on crate features
AppKit and AppKit_NSTextAttachment only.Implementations
Sourceimpl NSTextAttachment
impl NSTextAttachment
pub unsafe fn initWithData_ofType( this: Allocated<Self>, content_data: Option<&NSData>, uti: Option<&NSString>, ) -> Id<Self>
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitAvailable on crate features
Foundation_NSData and Foundation_NSString only.pub unsafe fn initWithFileWrapper( this: Allocated<Self>, file_wrapper: Option<&NSFileWrapper>, ) -> Id<Self>
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitAvailable on crate feature
Foundation_NSFileWrapper only.pub unsafe fn contents(&self) -> Option<Id<NSData>>
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitAvailable on crate feature
Foundation_NSData only.pub unsafe fn setContents(&self, contents: Option<&NSData>)
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitAvailable on crate feature
Foundation_NSData only.pub unsafe fn fileType(&self) -> Option<Id<NSString>>
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitAvailable on crate feature
Foundation_NSString only.pub unsafe fn setFileType(&self, file_type: Option<&NSString>)
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitAvailable on crate feature
Foundation_NSString only.pub unsafe fn image(&self) -> Option<Id<NSImage>>
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitAvailable on crate feature
AppKit_NSImage only.pub unsafe fn setImage(&self, image: Option<&NSImage>)
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitAvailable on crate feature
AppKit_NSImage only.pub unsafe fn bounds(&self) -> CGRect
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitpub unsafe fn setBounds(&self, bounds: CGRect)
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitpub unsafe fn fileWrapper(&self) -> Option<Id<NSFileWrapper>>
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitAvailable on crate feature
Foundation_NSFileWrapper only.pub unsafe fn setFileWrapper(&self, file_wrapper: Option<&NSFileWrapper>)
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitAvailable on crate feature
Foundation_NSFileWrapper only.pub unsafe fn attachmentCell( &self, ) -> Option<Id<ProtocolObject<dyn NSTextAttachmentCellProtocol>>>
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitpub unsafe fn setAttachmentCell( &self, attachment_cell: Option<&ProtocolObject<dyn NSTextAttachmentCellProtocol>>, )
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitpub unsafe fn lineLayoutPadding(&self) -> CGFloat
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitpub unsafe fn setLineLayoutPadding(&self, line_layout_padding: CGFloat)
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitpub unsafe fn textAttachmentViewProviderClassForFileType( file_type: &NSString, ) -> Option<&'static AnyClass>
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitAvailable on crate feature
Foundation_NSString only.pub unsafe fn registerTextAttachmentViewProviderClass_forFileType( text_attachment_view_provider_class: &AnyClass, file_type: &NSString, )
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitAvailable on crate feature
Foundation_NSString only.pub unsafe fn allowsTextAttachmentView(&self) -> bool
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitpub unsafe fn setAllowsTextAttachmentView( &self, allows_text_attachment_view: bool, )
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitpub unsafe fn usesTextAttachmentView(&self) -> bool
👎Deprecated:
icrate::AppKit has been moved to objc2-app-kitMethods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Available on crate feature AuthenticationServices only.
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
AuthenticationServices only.Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.