#[repr(C)]pub struct CXAction { /* private fields */ }👎Deprecated:
icrate::CallKit has been moved to objc2-call-kitAvailable on crate features
CallKit and CallKit_CXAction only.Implementations
Sourceimpl CXAction
impl CXAction
pub unsafe fn UUID(&self) -> Id<NSUUID>
👎Deprecated:
icrate::CallKit has been moved to objc2-call-kitAvailable on crate feature
Foundation_NSUUID only.pub unsafe fn isComplete(&self) -> bool
👎Deprecated:
icrate::CallKit has been moved to objc2-call-kitpub unsafe fn timeoutDate(&self) -> Id<NSDate>
👎Deprecated:
icrate::CallKit has been moved to objc2-call-kitAvailable on crate feature
Foundation_NSDate only.pub unsafe fn init(this: Allocated<Self>) -> Id<Self>
👎Deprecated:
icrate::CallKit has been moved to objc2-call-kitpub unsafe fn initWithCoder( this: Allocated<Self>, a_decoder: &NSCoder, ) -> Option<Id<Self>>
👎Deprecated:
icrate::CallKit has been moved to objc2-call-kitAvailable on crate feature
Foundation_NSCoder only.pub unsafe fn fulfill(&self)
👎Deprecated:
icrate::CallKit has been moved to objc2-call-kitpub unsafe fn fail(&self)
👎Deprecated:
icrate::CallKit has been moved to objc2-call-kitMethods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Available on crate feature AuthenticationServices only.
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
AuthenticationServices only.Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.