#[repr(C)]pub struct NSFetchIndexDescription { /* private fields */ }👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData and CoreData_NSFetchIndexDescription only.Implementations
Sourceimpl NSFetchIndexDescription
impl NSFetchIndexDescription
pub unsafe fn initWithName_elements( this: Allocated<Self>, name: &NSString, elements: Option<&NSArray<NSFetchIndexElementDescription>>, ) -> Id<Self>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSFetchIndexElementDescription and Foundation_NSArray and Foundation_NSString only.pub unsafe fn name(&self) -> Id<NSString>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSString only.pub unsafe fn setName(&self, name: &NSString)
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSString only.pub unsafe fn elements(&self) -> Id<NSArray<NSFetchIndexElementDescription>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSFetchIndexElementDescription and Foundation_NSArray only.pub unsafe fn setElements( &self, elements: &NSArray<NSFetchIndexElementDescription>, )
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSFetchIndexElementDescription and Foundation_NSArray only.pub unsafe fn entity(&self) -> Option<Id<NSEntityDescription>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSEntityDescription only.pub unsafe fn partialIndexPredicate(&self) -> Option<Id<NSPredicate>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSPredicate only.pub unsafe fn setPartialIndexPredicate( &self, partial_index_predicate: Option<&NSPredicate>, )
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSPredicate only.Sourceimpl NSFetchIndexDescription
Methods declared on superclass NSObject
impl NSFetchIndexDescription
Methods declared on superclass NSObject
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Available on crate feature AuthenticationServices only.
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
AuthenticationServices only.Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.