#[repr(C)]pub struct NSFetchIndexElementDescription { /* private fields */ }👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData and CoreData_NSFetchIndexElementDescription only.Implementations
Sourceimpl NSFetchIndexElementDescription
impl NSFetchIndexElementDescription
pub unsafe fn initWithProperty_collationType( this: Allocated<Self>, property: &NSPropertyDescription, collation_type: NSFetchIndexElementType, ) -> Id<Self>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSPropertyDescription only.pub unsafe fn property(&self) -> Option<Id<NSPropertyDescription>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSPropertyDescription only.pub unsafe fn propertyName(&self) -> Option<Id<NSString>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSString only.pub unsafe fn collationType(&self) -> NSFetchIndexElementType
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn setCollationType(&self, collation_type: NSFetchIndexElementType)
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn isAscending(&self) -> bool
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn setAscending(&self, ascending: bool)
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn indexDescription(&self) -> Option<Id<NSFetchIndexDescription>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSFetchIndexDescription only.Sourceimpl NSFetchIndexElementDescription
Methods declared on superclass NSObject
impl NSFetchIndexElementDescription
Methods declared on superclass NSObject
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Available on crate feature AuthenticationServices only.
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
AuthenticationServices only.Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.