#[repr(C)]pub struct NSIncrementalStoreNode { /* private fields */ }👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData and CoreData_NSIncrementalStoreNode only.Implementations
Sourceimpl NSIncrementalStoreNode
impl NSIncrementalStoreNode
pub unsafe fn initWithObjectID_withValues_version( this: Allocated<Self>, object_id: &NSManagedObjectID, values: &NSDictionary<NSString, AnyObject>, version: u64, ) -> Id<Self>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSManagedObjectID and Foundation_NSDictionary and Foundation_NSString only.pub unsafe fn updateWithValues_version( &self, values: &NSDictionary<NSString, AnyObject>, version: u64, )
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
Foundation_NSDictionary and Foundation_NSString only.pub unsafe fn objectID(&self) -> Id<NSManagedObjectID>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSManagedObjectID only.pub unsafe fn version(&self) -> u64
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn valueForPropertyDescription( &self, prop: &NSPropertyDescription, ) -> Option<Id<AnyObject>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSPropertyDescription only.Sourceimpl NSIncrementalStoreNode
Methods declared on superclass NSObject
impl NSIncrementalStoreNode
Methods declared on superclass NSObject
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Available on crate feature AuthenticationServices only.
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
AuthenticationServices only.Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.