#[repr(C)]pub struct NSMergePolicy { /* private fields */ }👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData and CoreData_NSMergePolicy only.Implementations
Sourceimpl NSMergePolicy
impl NSMergePolicy
pub unsafe fn errorMergePolicy() -> Id<NSMergePolicy>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn rollbackMergePolicy() -> Id<NSMergePolicy>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn overwriteMergePolicy() -> Id<NSMergePolicy>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn mergeByPropertyObjectTrumpMergePolicy() -> Id<NSMergePolicy>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn mergeByPropertyStoreTrumpMergePolicy() -> Id<NSMergePolicy>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn mergeType(&self) -> NSMergePolicyType
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn initWithMergeType( this: Allocated<Self>, ty: NSMergePolicyType, ) -> Id<Self>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn init(this: Allocated<Self>) -> Id<Self>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn resolveConflicts_error( &self, list: &NSArray, ) -> Result<(), Id<NSError>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
Foundation_NSArray and Foundation_NSError only.pub unsafe fn resolveOptimisticLockingVersionConflicts_error( &self, list: &NSArray<NSMergeConflict>, ) -> Result<(), Id<NSError>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSMergeConflict and Foundation_NSArray and Foundation_NSError only.pub unsafe fn resolveConstraintConflicts_error( &self, list: &NSArray<NSConstraintConflict>, ) -> Result<(), Id<NSError>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSConstraintConflict and Foundation_NSArray and Foundation_NSError only.Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Available on crate feature AuthenticationServices only.
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
AuthenticationServices only.Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.