#[repr(C)]pub struct NSPersistentCloudKitContainer { /* private fields */ }👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData and CoreData_NSPersistentCloudKitContainer only.Implementations
Sourceimpl NSPersistentCloudKitContainer
impl NSPersistentCloudKitContainer
pub unsafe fn initializeCloudKitSchemaWithOptions_error( &self, options: NSPersistentCloudKitContainerSchemaInitializationOptions, ) -> Result<(), Id<NSError>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSError only.pub unsafe fn canUpdateRecordForManagedObjectWithID( &self, object_id: &NSManagedObjectID, ) -> bool
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSManagedObjectID only.pub unsafe fn canDeleteRecordForManagedObjectWithID( &self, object_id: &NSManagedObjectID, ) -> bool
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSManagedObjectID only.pub unsafe fn canModifyManagedObjectsInStore( &self, store: &NSPersistentStore, ) -> bool
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSPersistentStore only.Sourceimpl NSPersistentCloudKitContainer
Methods declared on superclass NSPersistentContainer
impl NSPersistentCloudKitContainer
Methods declared on superclass NSPersistentContainer
pub unsafe fn persistentContainerWithName(name: &NSString) -> Id<Self>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSString only.pub unsafe fn persistentContainerWithName_managedObjectModel( name: &NSString, model: &NSManagedObjectModel, ) -> Id<Self>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSManagedObjectModel and Foundation_NSString only.pub unsafe fn initWithName(this: Allocated<Self>, name: &NSString) -> Id<Self>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSString only.pub unsafe fn initWithName_managedObjectModel( this: Allocated<Self>, name: &NSString, model: &NSManagedObjectModel, ) -> Id<Self>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSManagedObjectModel and Foundation_NSString only.Sourceimpl NSPersistentCloudKitContainer
Methods declared on superclass NSObject
impl NSPersistentCloudKitContainer
Methods declared on superclass NSObject
Methods from Deref<Target = NSPersistentContainer>
pub unsafe fn name(&self) -> Id<NSString>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSPersistentContainer and Foundation_NSString only.pub unsafe fn viewContext(&self) -> Id<NSManagedObjectContext>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSPersistentContainer and CoreData_NSManagedObjectContext only.pub unsafe fn managedObjectModel(&self) -> Id<NSManagedObjectModel>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSPersistentContainer and CoreData_NSManagedObjectModel only.pub unsafe fn persistentStoreCoordinator( &self, ) -> Id<NSPersistentStoreCoordinator>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSPersistentContainer and CoreData_NSPersistentStoreCoordinator only.pub unsafe fn persistentStoreDescriptions( &self, ) -> Id<NSArray<NSPersistentStoreDescription>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSPersistentContainer and CoreData_NSPersistentStoreDescription and Foundation_NSArray only.pub unsafe fn setPersistentStoreDescriptions( &self, persistent_store_descriptions: &NSArray<NSPersistentStoreDescription>, )
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSPersistentContainer and CoreData_NSPersistentStoreDescription and Foundation_NSArray only.pub unsafe fn loadPersistentStoresWithCompletionHandler( &self, block: &Block<(NonNull<NSPersistentStoreDescription>, *mut NSError), ()>, )
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSPersistentContainer and CoreData_NSPersistentStoreDescription and Foundation_NSError only.pub unsafe fn newBackgroundContext(&self) -> Id<NSManagedObjectContext>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSPersistentContainer and CoreData_NSManagedObjectContext only.pub unsafe fn performBackgroundTask( &self, block: &Block<(NonNull<NSManagedObjectContext>,), ()>, )
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSPersistentContainer and CoreData_NSManagedObjectContext only.Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Available on crate feature AuthenticationServices only.
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
AuthenticationServices only.Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.