#[repr(C)]pub struct NSPersistentCloudKitContainerEvent { /* private fields */ }👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData and CoreData_NSPersistentCloudKitContainerEvent only.Implementations
Sourceimpl NSPersistentCloudKitContainerEvent
impl NSPersistentCloudKitContainerEvent
pub unsafe fn identifier(&self) -> Id<NSUUID>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSUUID only.pub unsafe fn storeIdentifier(&self) -> Id<NSString>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSString only.pub unsafe fn type(&self) -> NSPersistentCloudKitContainerEventType
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn startDate(&self) -> Id<NSDate>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSDate only.pub unsafe fn endDate(&self) -> Option<Id<NSDate>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSDate only.pub unsafe fn succeeded(&self) -> bool
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn error(&self) -> Option<Id<NSError>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSError only.pub unsafe fn new() -> Id<Self>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn init(this: Allocated<Self>) -> Id<Self>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataMethods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Available on crate feature AuthenticationServices only.
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
AuthenticationServices only.Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.