#[repr(C)]pub struct NSPersistentHistoryChange { /* private fields */ }👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData and CoreData_NSPersistentHistoryChange only.Implementations
Sourceimpl NSPersistentHistoryChange
impl NSPersistentHistoryChange
pub unsafe fn entityDescriptionWithContext( context: &NSManagedObjectContext, ) -> Option<Id<NSEntityDescription>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSEntityDescription and CoreData_NSManagedObjectContext only.pub unsafe fn entityDescription() -> Option<Id<NSEntityDescription>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSEntityDescription only.pub unsafe fn fetchRequest() -> Option<Id<NSFetchRequest>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSFetchRequest only.pub unsafe fn changeID(&self) -> i64
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn changedObjectID(&self) -> Id<NSManagedObjectID>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSManagedObjectID only.pub unsafe fn changeType(&self) -> NSPersistentHistoryChangeType
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn tombstone(&self) -> Option<Id<NSDictionary>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSDictionary only.pub unsafe fn transaction(&self) -> Option<Id<NSPersistentHistoryTransaction>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSPersistentHistoryTransaction only.pub unsafe fn updatedProperties( &self, ) -> Option<Id<NSSet<NSPropertyDescription>>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSPropertyDescription and Foundation_NSSet only.Sourceimpl NSPersistentHistoryChange
Methods declared on superclass NSObject
impl NSPersistentHistoryChange
Methods declared on superclass NSObject
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Available on crate feature AuthenticationServices only.
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
AuthenticationServices only.Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.