#[repr(C)]pub struct NSPersistentHistoryChangeRequest { /* private fields */ }👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData and CoreData_NSPersistentHistoryChangeRequest only.Implementations
Sourceimpl NSPersistentHistoryChangeRequest
impl NSPersistentHistoryChangeRequest
pub unsafe fn fetchHistoryAfterDate(date: &NSDate) -> Id<Self>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSDate only.pub unsafe fn fetchHistoryAfterToken( token: Option<&NSPersistentHistoryToken>, ) -> Id<Self>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSPersistentHistoryToken only.pub unsafe fn fetchHistoryAfterTransaction( transaction: Option<&NSPersistentHistoryTransaction>, ) -> Id<Self>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSPersistentHistoryTransaction only.pub unsafe fn fetchHistoryWithFetchRequest( fetch_request: &NSFetchRequest, ) -> Id<Self>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSFetchRequest only.pub unsafe fn deleteHistoryBeforeDate(date: &NSDate) -> Id<Self>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSDate only.pub unsafe fn deleteHistoryBeforeToken( token: Option<&NSPersistentHistoryToken>, ) -> Id<Self>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSPersistentHistoryToken only.pub unsafe fn deleteHistoryBeforeTransaction( transaction: Option<&NSPersistentHistoryTransaction>, ) -> Id<Self>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSPersistentHistoryTransaction only.pub unsafe fn resultType(&self) -> NSPersistentHistoryResultType
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn setResultType(&self, result_type: NSPersistentHistoryResultType)
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn token(&self) -> Option<Id<NSPersistentHistoryToken>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSPersistentHistoryToken only.pub unsafe fn fetchRequest(&self) -> Option<Id<NSFetchRequest>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSFetchRequest only.pub unsafe fn setFetchRequest(&self, fetch_request: Option<&NSFetchRequest>)
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSFetchRequest only.Sourceimpl NSPersistentHistoryChangeRequest
Methods declared on superclass NSObject
impl NSPersistentHistoryChangeRequest
Methods declared on superclass NSObject
Methods from Deref<Target = NSPersistentStoreRequest>
pub unsafe fn affectedStores(&self) -> Option<Id<NSArray<NSPersistentStore>>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSPersistentStoreRequest and CoreData_NSPersistentStore and Foundation_NSArray only.pub unsafe fn setAffectedStores( &self, affected_stores: Option<&NSArray<NSPersistentStore>>, )
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSPersistentStoreRequest and CoreData_NSPersistentStore and Foundation_NSArray only.pub unsafe fn requestType(&self) -> NSPersistentStoreRequestType
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSPersistentStoreRequest only.Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Available on crate feature AuthenticationServices only.
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
AuthenticationServices only.Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.