#[repr(C)]pub struct NSPersistentStore { /* private fields */ }👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData and CoreData_NSPersistentStore only.Implementations
Sourceimpl NSPersistentStore
impl NSPersistentStore
pub unsafe fn metadataForPersistentStoreWithURL_error( url: &NSURL, ) -> Result<Id<NSDictionary<NSString, AnyObject>>, Id<NSError>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
Foundation_NSDictionary and Foundation_NSError and Foundation_NSString and Foundation_NSURL only.pub unsafe fn setMetadata_forPersistentStoreWithURL_error( metadata: Option<&NSDictionary<NSString, AnyObject>>, url: &NSURL, ) -> Result<(), Id<NSError>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
Foundation_NSDictionary and Foundation_NSError and Foundation_NSString and Foundation_NSURL only.pub unsafe fn migrationManagerClass() -> &'static AnyClass
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn initWithPersistentStoreCoordinator_configurationName_URL_options( this: Allocated<Self>, root: Option<&NSPersistentStoreCoordinator>, name: Option<&NSString>, url: &NSURL, options: Option<&NSDictionary>, ) -> Id<Self>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
CoreData_NSPersistentStoreCoordinator and Foundation_NSDictionary and Foundation_NSString and Foundation_NSURL only.pub unsafe fn init(this: Allocated<Self>) -> Id<Self>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn loadMetadata(&self) -> Result<(), Id<NSError>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSError only.pub unsafe fn persistentStoreCoordinator( &self, ) -> Option<Id<NSPersistentStoreCoordinator>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSPersistentStoreCoordinator only.pub unsafe fn configurationName(&self) -> Id<NSString>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSString only.pub unsafe fn options(&self) -> Option<Id<NSDictionary>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSDictionary only.pub unsafe fn URL(&self) -> Option<Id<NSURL>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSURL only.pub unsafe fn setURL(&self, url: Option<&NSURL>)
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSURL only.pub unsafe fn identifier(&self) -> Id<NSString>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSString only.pub unsafe fn setIdentifier(&self, identifier: Option<&NSString>)
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSString only.pub unsafe fn type(&self) -> Id<NSString>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
Foundation_NSString only.pub unsafe fn isReadOnly(&self) -> bool
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn setReadOnly(&self, read_only: bool)
👎Deprecated:
icrate::CoreData has been moved to objc2-core-datapub unsafe fn metadata(&self) -> Option<Id<NSDictionary<NSString, AnyObject>>>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
Foundation_NSDictionary and Foundation_NSString only.pub unsafe fn setMetadata( &self, metadata: Option<&NSDictionary<NSString, AnyObject>>, )
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate features
Foundation_NSDictionary and Foundation_NSString only.pub unsafe fn didAddToPersistentStoreCoordinator( &self, coordinator: &NSPersistentStoreCoordinator, )
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSPersistentStoreCoordinator only.pub unsafe fn willRemoveFromPersistentStoreCoordinator( &self, coordinator: Option<&NSPersistentStoreCoordinator>, )
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSPersistentStoreCoordinator only.pub unsafe fn coreSpotlightExporter( &self, ) -> Id<NSCoreDataCoreSpotlightDelegate>
👎Deprecated:
icrate::CoreData has been moved to objc2-core-dataAvailable on crate feature
CoreData_NSCoreDataCoreSpotlightDelegate only.Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Available on crate feature AuthenticationServices only.
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
AuthenticationServices only.Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.