#[repr(C)]pub struct CLRegion { /* private fields */ }👎Deprecated:
icrate::CoreLocation has been moved to objc2-core-locationAvailable on crate features
CoreLocation and CoreLocation_CLRegion only.Implementations
Sourceimpl CLRegion
impl CLRegion
pub unsafe fn initCircularRegionWithCenter_radius_identifier( this: Allocated<Self>, center: CLLocationCoordinate2D, radius: CLLocationDistance, identifier: &NSString, ) -> Id<Self>
👎Deprecated: Please see CLCircularRegion
Available on crate feature
Foundation_NSString only.pub unsafe fn center(&self) -> CLLocationCoordinate2D
👎Deprecated: Please see CLCircularRegion
pub unsafe fn radius(&self) -> CLLocationDistance
👎Deprecated: Please see CLCircularRegion
pub unsafe fn identifier(&self) -> Id<NSString>
👎Deprecated:
icrate::CoreLocation has been moved to objc2-core-locationAvailable on crate feature
Foundation_NSString only.pub unsafe fn notifyOnEntry(&self) -> bool
👎Deprecated:
icrate::CoreLocation has been moved to objc2-core-locationpub unsafe fn setNotifyOnEntry(&self, notify_on_entry: bool)
👎Deprecated:
icrate::CoreLocation has been moved to objc2-core-locationpub unsafe fn notifyOnExit(&self) -> bool
👎Deprecated:
icrate::CoreLocation has been moved to objc2-core-locationpub unsafe fn setNotifyOnExit(&self, notify_on_exit: bool)
👎Deprecated:
icrate::CoreLocation has been moved to objc2-core-locationpub unsafe fn containsCoordinate( &self, coordinate: CLLocationCoordinate2D, ) -> bool
👎Deprecated: Please see CLCircularRegion
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Available on crate feature AuthenticationServices only.
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
AuthenticationServices only.Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.