#[repr(C)]pub struct EKCalendar { /* private fields */ }👎Deprecated:
icrate::EventKit has been moved to objc2-event-kitAvailable on crate features
EventKit and EventKit_EKCalendar only.Implementations
Sourceimpl EKCalendar
impl EKCalendar
pub unsafe fn calendarWithEventStore( event_store: &EKEventStore, ) -> Id<EKCalendar>
👎Deprecated:
icrate::EventKit has been moved to objc2-event-kitAvailable on crate feature
EventKit_EKEventStore only.pub unsafe fn calendarForEntityType_eventStore( entity_type: EKEntityType, event_store: &EKEventStore, ) -> Id<EKCalendar>
👎Deprecated:
icrate::EventKit has been moved to objc2-event-kitAvailable on crate feature
EventKit_EKEventStore only.pub unsafe fn source(&self) -> Option<Id<EKSource>>
👎Deprecated:
icrate::EventKit has been moved to objc2-event-kitAvailable on crate feature
EventKit_EKSource only.pub unsafe fn setSource(&self, source: Option<&EKSource>)
👎Deprecated:
icrate::EventKit has been moved to objc2-event-kitAvailable on crate feature
EventKit_EKSource only.pub unsafe fn calendarIdentifier(&self) -> Id<NSString>
👎Deprecated:
icrate::EventKit has been moved to objc2-event-kitAvailable on crate feature
Foundation_NSString only.pub unsafe fn title(&self) -> Id<NSString>
👎Deprecated:
icrate::EventKit has been moved to objc2-event-kitAvailable on crate feature
Foundation_NSString only.pub unsafe fn setTitle(&self, title: &NSString)
👎Deprecated:
icrate::EventKit has been moved to objc2-event-kitAvailable on crate feature
Foundation_NSString only.pub unsafe fn type(&self) -> EKCalendarType
👎Deprecated:
icrate::EventKit has been moved to objc2-event-kitpub unsafe fn allowsContentModifications(&self) -> bool
👎Deprecated:
icrate::EventKit has been moved to objc2-event-kitpub unsafe fn isSubscribed(&self) -> bool
👎Deprecated:
icrate::EventKit has been moved to objc2-event-kitpub unsafe fn isImmutable(&self) -> bool
👎Deprecated:
icrate::EventKit has been moved to objc2-event-kitpub unsafe fn color(&self) -> Id<NSColor>
👎Deprecated:
icrate::EventKit has been moved to objc2-event-kitAvailable on crate feature
AppKit_NSColor only.pub unsafe fn setColor(&self, color: Option<&NSColor>)
👎Deprecated:
icrate::EventKit has been moved to objc2-event-kitAvailable on crate feature
AppKit_NSColor only.pub unsafe fn supportedEventAvailabilities( &self, ) -> EKCalendarEventAvailabilityMask
👎Deprecated:
icrate::EventKit has been moved to objc2-event-kitpub unsafe fn allowedEntityTypes(&self) -> EKEntityMask
👎Deprecated:
icrate::EventKit has been moved to objc2-event-kitMethods from Deref<Target = EKObject>
pub unsafe fn hasChanges(&self) -> bool
👎Deprecated:
icrate::EventKit has been moved to objc2-event-kitAvailable on crate feature
EventKit_EKObject only.pub unsafe fn isNew(&self) -> bool
👎Deprecated:
icrate::EventKit has been moved to objc2-event-kitAvailable on crate feature
EventKit_EKObject only.pub unsafe fn reset(&self)
👎Deprecated:
icrate::EventKit has been moved to objc2-event-kitAvailable on crate feature
EventKit_EKObject only.pub unsafe fn rollback(&self)
👎Deprecated:
icrate::EventKit has been moved to objc2-event-kitAvailable on crate feature
EventKit_EKObject only.pub unsafe fn refresh(&self) -> bool
👎Deprecated:
icrate::EventKit has been moved to objc2-event-kitAvailable on crate feature
EventKit_EKObject only.Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Available on crate feature AuthenticationServices only.
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
AuthenticationServices only.Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.