Struct EKEventStore

#[repr(C)]
pub struct EKEventStore { /* private fields */ }
👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit and EventKit_EKEventStore only.

Implementations

Source

impl EKEventStore

pub unsafe fn authorizationStatusForEntityType( entity_type: EKEntityType, ) -> EKAuthorizationStatus

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
pub unsafe fn initWithAccessToEntityTypes( this: Allocated<Self>, entity_types: EKEntityMask, ) -> Id<Self>

👎Deprecated
pub unsafe fn init(this: Allocated<Self>) -> Id<Self>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
pub unsafe fn initWithSources( this: Allocated<Self>, sources: &NSArray<EKSource>, ) -> Id<Self>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKSource and Foundation_NSArray only.
pub unsafe fn requestFullAccessToEventsWithCompletion( &self, completion: EKEventStoreRequestAccessCompletionHandler, )

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
pub unsafe fn requestWriteOnlyAccessToEventsWithCompletion( &self, completion: EKEventStoreRequestAccessCompletionHandler, )

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
pub unsafe fn requestFullAccessToRemindersWithCompletion( &self, completion: EKEventStoreRequestAccessCompletionHandler, )

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
pub unsafe fn requestAccessToEntityType_completion( &self, entity_type: EKEntityType, completion: EKEventStoreRequestAccessCompletionHandler, )

👎Deprecated: Use -requestFullAccessToEventsWithCompletion:, -requestWriteOnlyAccessToEventsWithCompletion:, or -requestFullAccessToRemindersWithCompletion:
pub unsafe fn eventStoreIdentifier(&self) -> Id<NSString>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate feature Foundation_NSString only.
pub unsafe fn delegateSources(&self) -> Id<NSArray<EKSource>>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKSource and Foundation_NSArray only.
pub unsafe fn sources(&self) -> Id<NSArray<EKSource>>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKSource and Foundation_NSArray only.
pub unsafe fn sourceWithIdentifier( &self, identifier: &NSString, ) -> Option<Id<EKSource>>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKSource and Foundation_NSString only.
pub unsafe fn calendars(&self) -> Id<NSArray<EKCalendar>>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKCalendar and Foundation_NSArray only.
pub unsafe fn calendarsForEntityType( &self, entity_type: EKEntityType, ) -> Id<NSArray<EKCalendar>>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKCalendar and Foundation_NSArray only.
pub unsafe fn defaultCalendarForNewEvents(&self) -> Option<Id<EKCalendar>>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate feature EventKit_EKCalendar only.
pub unsafe fn defaultCalendarForNewReminders(&self) -> Option<Id<EKCalendar>>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate feature EventKit_EKCalendar only.
pub unsafe fn calendarWithIdentifier( &self, identifier: &NSString, ) -> Option<Id<EKCalendar>>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKCalendar and Foundation_NSString only.
pub unsafe fn saveCalendar_commit_error( &self, calendar: &EKCalendar, commit: bool, ) -> Result<(), Id<NSError>>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKCalendar and Foundation_NSError only.
pub unsafe fn removeCalendar_commit_error( &self, calendar: &EKCalendar, commit: bool, ) -> Result<(), Id<NSError>>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKCalendar and Foundation_NSError only.
pub unsafe fn calendarItemWithIdentifier( &self, identifier: &NSString, ) -> Option<Id<EKCalendarItem>>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKCalendarItem and Foundation_NSString only.
pub unsafe fn calendarItemsWithExternalIdentifier( &self, external_identifier: &NSString, ) -> Id<NSArray<EKCalendarItem>>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKCalendarItem and Foundation_NSArray and Foundation_NSString only.
pub unsafe fn saveEvent_span_error( &self, event: &EKEvent, span: EKSpan, ) -> Result<(), Id<NSError>>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKEvent and Foundation_NSError only.
pub unsafe fn removeEvent_span_error( &self, event: &EKEvent, span: EKSpan, ) -> Result<(), Id<NSError>>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKEvent and Foundation_NSError only.
pub unsafe fn saveEvent_span_commit_error( &self, event: &EKEvent, span: EKSpan, commit: bool, ) -> Result<(), Id<NSError>>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKEvent and Foundation_NSError only.
pub unsafe fn removeEvent_span_commit_error( &self, event: &EKEvent, span: EKSpan, commit: bool, ) -> Result<(), Id<NSError>>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKEvent and Foundation_NSError only.
pub unsafe fn eventWithIdentifier( &self, identifier: &NSString, ) -> Option<Id<EKEvent>>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKEvent and Foundation_NSString only.
pub unsafe fn eventsMatchingPredicate( &self, predicate: &NSPredicate, ) -> Id<NSArray<EKEvent>>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKEvent and Foundation_NSArray and Foundation_NSPredicate only.
pub unsafe fn enumerateEventsMatchingPredicate_usingBlock( &self, predicate: &NSPredicate, block: EKEventSearchCallback, )

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate feature Foundation_NSPredicate only.
pub unsafe fn predicateForEventsWithStartDate_endDate_calendars( &self, start_date: &NSDate, end_date: &NSDate, calendars: Option<&NSArray<EKCalendar>>, ) -> Id<NSPredicate>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKCalendar and Foundation_NSArray and Foundation_NSDate and Foundation_NSPredicate only.
pub unsafe fn saveReminder_commit_error( &self, reminder: &EKReminder, commit: bool, ) -> Result<(), Id<NSError>>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKReminder and Foundation_NSError only.
pub unsafe fn removeReminder_commit_error( &self, reminder: &EKReminder, commit: bool, ) -> Result<(), Id<NSError>>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKReminder and Foundation_NSError only.
pub unsafe fn fetchRemindersMatchingPredicate_completion( &self, predicate: &NSPredicate, completion: &Block<(*mut NSArray<EKReminder>,), ()>, ) -> Id<AnyObject>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKReminder and Foundation_NSArray and Foundation_NSPredicate only.
pub unsafe fn cancelFetchRequest(&self, fetch_identifier: &AnyObject)

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
pub unsafe fn predicateForRemindersInCalendars( &self, calendars: Option<&NSArray<EKCalendar>>, ) -> Id<NSPredicate>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKCalendar and Foundation_NSArray and Foundation_NSPredicate only.
pub unsafe fn predicateForIncompleteRemindersWithDueDateStarting_ending_calendars( &self, start_date: Option<&NSDate>, end_date: Option<&NSDate>, calendars: Option<&NSArray<EKCalendar>>, ) -> Id<NSPredicate>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKCalendar and Foundation_NSArray and Foundation_NSDate and Foundation_NSPredicate only.
pub unsafe fn predicateForCompletedRemindersWithCompletionDateStarting_ending_calendars( &self, start_date: Option<&NSDate>, end_date: Option<&NSDate>, calendars: Option<&NSArray<EKCalendar>>, ) -> Id<NSPredicate>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate features EventKit_EKCalendar and Foundation_NSArray and Foundation_NSDate and Foundation_NSPredicate only.
pub unsafe fn commit(&self) -> Result<(), Id<NSError>>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Available on crate feature Foundation_NSError only.
pub unsafe fn reset(&self)

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
pub unsafe fn refreshSourcesIfNecessary(&self)

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit
Source

impl EKEventStore

Methods declared on superclass NSObject

pub unsafe fn new() -> Id<Self>

👎Deprecated: icrate::EventKit has been moved to objc2-event-kit

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Available on crate feature AuthenticationServices only.

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.

Use Ivar::load_mut instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.