Struct NSCoder

#[repr(C)]
pub struct NSCoder { /* private fields */ }
👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate features Foundation and Foundation_NSCoder only.

Implementations

Source

impl NSCoder

NSAppKitColorExtensions

pub unsafe fn decodeNXColor(&self) -> Option<Id<NSColor>>

👎Deprecated
Available on crate features AppKit and AppKit_NSColor only.
Source

impl NSCoder

pub unsafe fn encodeValueOfObjCType_at( &self, type: NonNull<c_char>, addr: NonNull<c_void>, )

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn encodeDataObject(&self, data: &NSData)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSData only.
pub unsafe fn decodeDataObject(&self) -> Option<Id<NSData>>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSData only.
pub unsafe fn decodeValueOfObjCType_at_size( &self, type: NonNull<c_char>, data: NonNull<c_void>, size: NSUInteger, )

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn versionForClassName(&self, class_name: &NSString) -> NSInteger

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
Source

impl NSCoder

Methods declared on superclass NSObject

pub unsafe fn init(this: Allocated<Self>) -> Id<Self>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn new() -> Id<Self>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Source

impl NSCoder

NSExtendedCoder

pub unsafe fn encodeObject(&self, object: Option<&AnyObject>)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn encodeRootObject(&self, root_object: &AnyObject)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn encodeBycopyObject(&self, an_object: Option<&AnyObject>)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn encodeByrefObject(&self, an_object: Option<&AnyObject>)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn encodeConditionalObject(&self, object: Option<&AnyObject>)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn encodeArrayOfObjCType_count_at( &self, type: NonNull<c_char>, count: NSUInteger, array: NonNull<c_void>, )

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn encodeBytes_length( &self, byteaddr: *mut c_void, length: NSUInteger, )

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn decodeObject(&self) -> Option<Id<AnyObject>>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn decodeTopLevelObjectAndReturnError( &self, ) -> Result<Id<AnyObject>, Id<NSError>>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSError only.
pub unsafe fn decodeArrayOfObjCType_count_at( &self, item_type: NonNull<c_char>, count: NSUInteger, array: NonNull<c_void>, )

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn decodeBytesWithReturnedLength( &self, lengthp: NonNull<NSUInteger>, ) -> *mut c_void

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn encodePropertyList(&self, a_property_list: &AnyObject)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn decodePropertyList(&self) -> Option<Id<AnyObject>>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn setObjectZone(&self, zone: *mut NSZone)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn objectZone(&self) -> *mut NSZone

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn systemVersion(&self) -> c_uint

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn allowsKeyedCoding(&self) -> bool

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn encodeObject_forKey( &self, object: Option<&AnyObject>, key: &NSString, )

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn encodeConditionalObject_forKey( &self, object: Option<&AnyObject>, key: &NSString, )

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn encodeBool_forKey(&self, value: bool, key: &NSString)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn encodeInt_forKey(&self, value: c_int, key: &NSString)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn encodeInt32_forKey(&self, value: i32, key: &NSString)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn encodeInt64_forKey(&self, value: i64, key: &NSString)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn encodeFloat_forKey(&self, value: c_float, key: &NSString)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn encodeDouble_forKey(&self, value: c_double, key: &NSString)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn encodeBytes_length_forKey( &self, bytes: *mut u8, length: NSUInteger, key: &NSString, )

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn containsValueForKey(&self, key: &NSString) -> bool

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn decodeObjectForKey(&self, key: &NSString) -> Option<Id<AnyObject>>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn decodeTopLevelObjectForKey_error( &self, key: &NSString, ) -> Result<Id<AnyObject>, Id<NSError>>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate features Foundation_NSError and Foundation_NSString only.
pub unsafe fn decodeBoolForKey(&self, key: &NSString) -> bool

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn decodeIntForKey(&self, key: &NSString) -> c_int

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn decodeInt32ForKey(&self, key: &NSString) -> i32

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn decodeInt64ForKey(&self, key: &NSString) -> i64

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn decodeFloatForKey(&self, key: &NSString) -> c_float

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn decodeDoubleForKey(&self, key: &NSString) -> c_double

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn decodeBytesForKey_returnedLength( &self, key: &NSString, lengthp: *mut NSUInteger, ) -> *mut u8

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn encodeInteger_forKey(&self, value: NSInteger, key: &NSString)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn decodeIntegerForKey(&self, key: &NSString) -> NSInteger

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn requiresSecureCoding(&self) -> bool

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn decodeObjectOfClass_forKey( &self, a_class: &AnyClass, key: &NSString, ) -> Option<Id<AnyObject>>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn decodeTopLevelObjectOfClass_forKey_error( &self, a_class: &AnyClass, key: &NSString, ) -> Result<Id<AnyObject>, Id<NSError>>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate features Foundation_NSError and Foundation_NSString only.
pub unsafe fn decodeArrayOfObjectsOfClass_forKey( &self, cls: &AnyClass, key: &NSString, ) -> Option<Id<NSArray>>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate features Foundation_NSArray and Foundation_NSString only.
pub unsafe fn decodeDictionaryWithKeysOfClass_objectsOfClass_forKey( &self, key_cls: &AnyClass, object_cls: &AnyClass, key: &NSString, ) -> Option<Id<NSDictionary>>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate features Foundation_NSDictionary and Foundation_NSString only.
pub unsafe fn decodeObjectOfClasses_forKey( &self, classes: Option<&NSSet<AnyObject>>, key: &NSString, ) -> Option<Id<AnyObject>>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate features Foundation_NSSet and Foundation_NSString only.
pub unsafe fn decodeTopLevelObjectOfClasses_forKey_error( &self, classes: Option<&NSSet<AnyObject>>, key: &NSString, ) -> Result<Id<AnyObject>, Id<NSError>>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate features Foundation_NSError and Foundation_NSSet and Foundation_NSString only.
pub unsafe fn decodeArrayOfObjectsOfClasses_forKey( &self, classes: &NSSet<AnyObject>, key: &NSString, ) -> Option<Id<NSArray>>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate features Foundation_NSArray and Foundation_NSSet and Foundation_NSString only.
pub unsafe fn decodeDictionaryWithKeysOfClasses_objectsOfClasses_forKey( &self, key_classes: &NSSet<AnyObject>, object_classes: &NSSet<AnyObject>, key: &NSString, ) -> Option<Id<NSDictionary>>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate features Foundation_NSDictionary and Foundation_NSSet and Foundation_NSString only.
pub unsafe fn decodePropertyListForKey( &self, key: &NSString, ) -> Option<Id<AnyObject>>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn allowedClasses(&self) -> Option<Id<NSSet<AnyObject>>>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSSet only.
pub unsafe fn failWithError(&self, error: &NSError)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSError only.
pub unsafe fn decodingFailurePolicy(&self) -> NSDecodingFailurePolicy

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn error(&self) -> Option<Id<NSError>>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSError only.
Source

impl NSCoder

NSTypedstreamCompatibility

pub unsafe fn encodeNXObject(&self, object: &AnyObject)

👎Deprecated: Not supported
pub unsafe fn decodeNXObject(&self) -> Option<Id<AnyObject>>

👎Deprecated: Not supported
Source

impl NSCoder

NSDeprecated

pub unsafe fn decodeValueOfObjCType_at( &self, type: NonNull<c_char>, data: NonNull<c_void>, )

👎Deprecated
Source

impl NSCoder

NSGeometryCoding

pub unsafe fn encodePoint(&self, point: NSPoint)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn decodePoint(&self) -> NSPoint

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn encodeSize(&self, size: NSSize)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn decodeSize(&self) -> NSSize

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn encodeRect(&self, rect: NSRect)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn decodeRect(&self) -> NSRect

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Source

impl NSCoder

NSGeometryKeyedCoding

pub unsafe fn encodePoint_forKey(&self, point: NSPoint, key: &NSString)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn encodeSize_forKey(&self, size: NSSize, key: &NSString)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn encodeRect_forKey(&self, rect: NSRect, key: &NSString)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn decodePointForKey(&self, key: &NSString) -> NSPoint

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn decodeSizeForKey(&self, key: &NSString) -> NSSize

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.
pub unsafe fn decodeRectForKey(&self, key: &NSString) -> NSRect

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSString only.

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Available on crate feature AuthenticationServices only.

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.

Use Ivar::load_mut instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.