#[repr(C)]pub struct NSComparisonPredicate { /* private fields */ }👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate features
Foundation and Foundation_NSComparisonPredicate only.Implementations
Sourceimpl NSComparisonPredicate
impl NSComparisonPredicate
pub unsafe fn predicateWithLeftExpression_rightExpression_modifier_type_options( lhs: &NSExpression, rhs: &NSExpression, modifier: NSComparisonPredicateModifier, type: NSPredicateOperatorType, options: NSComparisonPredicateOptions, ) -> Id<NSComparisonPredicate>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate feature
Foundation_NSExpression only.pub unsafe fn predicateWithLeftExpression_rightExpression_customSelector( lhs: &NSExpression, rhs: &NSExpression, selector: Sel, ) -> Id<NSComparisonPredicate>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate feature
Foundation_NSExpression only.pub unsafe fn initWithLeftExpression_rightExpression_modifier_type_options( this: Allocated<Self>, lhs: &NSExpression, rhs: &NSExpression, modifier: NSComparisonPredicateModifier, type: NSPredicateOperatorType, options: NSComparisonPredicateOptions, ) -> Id<Self>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate feature
Foundation_NSExpression only.pub unsafe fn initWithLeftExpression_rightExpression_customSelector( this: Allocated<Self>, lhs: &NSExpression, rhs: &NSExpression, selector: Sel, ) -> Id<Self>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate feature
Foundation_NSExpression only.pub unsafe fn initWithCoder( this: Allocated<Self>, coder: &NSCoder, ) -> Option<Id<Self>>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate feature
Foundation_NSCoder only.pub unsafe fn predicateOperatorType(&self) -> NSPredicateOperatorType
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationpub unsafe fn comparisonPredicateModifier( &self, ) -> NSComparisonPredicateModifier
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationpub unsafe fn leftExpression(&self) -> Id<NSExpression>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate feature
Foundation_NSExpression only.pub unsafe fn rightExpression(&self) -> Id<NSExpression>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate feature
Foundation_NSExpression only.pub unsafe fn customSelector(&self) -> Option<Sel>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationpub unsafe fn options(&self) -> NSComparisonPredicateOptions
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationSourceimpl NSComparisonPredicate
Methods declared on superclass NSObject
impl NSComparisonPredicate
Methods declared on superclass NSObject
Methods from Deref<Target = NSPredicate>
pub unsafe fn predicateFormat(&self) -> Id<NSString>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate features
Foundation_NSPredicate and Foundation_NSString only.pub unsafe fn predicateWithSubstitutionVariables( &self, variables: &NSDictionary<NSString, AnyObject>, ) -> Id<Self>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate features
Foundation_NSPredicate and Foundation_NSDictionary and Foundation_NSString only.pub unsafe fn evaluateWithObject(&self, object: Option<&AnyObject>) -> bool
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate feature
Foundation_NSPredicate only.pub unsafe fn evaluateWithObject_substitutionVariables( &self, object: Option<&AnyObject>, bindings: Option<&NSDictionary<NSString, AnyObject>>, ) -> bool
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate features
Foundation_NSPredicate and Foundation_NSDictionary and Foundation_NSString only.pub unsafe fn allowEvaluation(&self)
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate feature
Foundation_NSPredicate only.Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Available on crate feature AuthenticationServices only.
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
AuthenticationServices only.Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.