#[repr(C)]
pub struct NSMutableArray<ObjectType: Message = AnyObject> { /* private fields */ }
Available on crate features Foundation and Foundation_NSArray only.

Implementations

source

impl<T: Message> NSMutableArray<T>

source

pub fn from_vec(vec: Vec<Id<T>>) -> Id<Self>

Available on crate feature Foundation_NSMutableArray only.
source

pub fn from_id_slice(slice: &[Id<T>]) -> Id<Self>where T: IsIdCloneable,

Available on crate feature Foundation_NSMutableArray only.
source

pub fn from_slice(slice: &[&T]) -> Id<Self>where T: IsRetainable,

Available on crate feature Foundation_NSMutableArray only.
source

pub fn into_vec(array: Id<Self>) -> Vec<Id<T>>

Available on crate feature Foundation_NSMutableArray only.
source

impl<T: Message> NSMutableArray<T>

source

pub fn push(&mut self, obj: Id<T>)

Available on crate feature Foundation_NSMutableArray only.
source

pub fn insert(&mut self, index: usize, obj: Id<T>)

Available on crate feature Foundation_NSMutableArray only.
source

pub fn replace(&mut self, index: usize, obj: Id<T>) -> Result<Id<T>, Id<T>>

Available on crate feature Foundation_NSMutableArray only.
source

pub fn remove(&mut self, index: usize) -> Option<Id<T>>

Available on crate feature Foundation_NSMutableArray only.
source

pub fn pop(&mut self) -> Option<Id<T>>

Available on crate feature Foundation_NSMutableArray only.
source

pub fn sort_by<F: FnMut(&T, &T) -> Ordering>(&mut self, compare: F)

Available on crate feature Foundation_NSMutableArray only.
source

impl<ObjectType: Message> NSMutableArray<ObjectType>

Methods declared on superclass NSArray

NSArrayCreation

source

pub unsafe fn array() -> Id<Self>

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn arrayWithObject(an_object: &ObjectType) -> Id<Self>

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn arrayWithObjects_count( objects: NonNull<NonNull<ObjectType>>, cnt: NSUInteger ) -> Id<Self>

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn arrayWithArray(array: &NSArray<ObjectType>) -> Id<Self>

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn initWithArray( this: Option<Allocated<Self>>, array: &NSArray<ObjectType> ) -> Id<Self>

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn initWithArray_copyItems( this: Option<Allocated<Self>>, array: &NSArray<ObjectType>, flag: bool ) -> Id<Self>

Available on crate feature Foundation_NSMutableArray only.
source

impl<ObjectType: Message> NSMutableArray<ObjectType>

source

pub unsafe fn addObject(&mut self, an_object: &ObjectType)

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn insertObject_atIndex( &mut self, an_object: &ObjectType, index: NSUInteger )

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn removeLastObject(&mut self)

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn removeObjectAtIndex(&mut self, index: NSUInteger)

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn replaceObjectAtIndex_withObject( &mut self, index: NSUInteger, an_object: &ObjectType )

Available on crate feature Foundation_NSMutableArray only.
source

pub fn init(this: Option<Allocated<Self>>) -> Id<Self>

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn initWithCapacity( this: Option<Allocated<Self>>, num_items: NSUInteger ) -> Id<Self>

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn initWithCoder( this: Option<Allocated<Self>>, coder: &NSCoder ) -> Option<Id<Self>>

Available on crate features Foundation_NSMutableArray and Foundation_NSCoder only.
source

impl<ObjectType: Message> NSMutableArray<ObjectType>

Methods declared on superclass NSArray

source

pub unsafe fn initWithObjects_count( this: Option<Allocated<Self>>, objects: *mut NonNull<ObjectType>, cnt: NSUInteger ) -> Id<Self>

Available on crate feature Foundation_NSMutableArray only.
source

impl<ObjectType: Message> NSMutableArray<ObjectType>

Methods declared on superclass NSObject

source

pub fn new() -> Id<Self>

Available on crate feature Foundation_NSMutableArray only.
source

impl<ObjectType: Message> NSMutableArray<ObjectType>

NSExtendedMutableArray

source

pub unsafe fn addObjectsFromArray(&mut self, other_array: &NSArray<ObjectType>)

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn exchangeObjectAtIndex_withObjectAtIndex( &mut self, idx1: NSUInteger, idx2: NSUInteger )

Available on crate feature Foundation_NSMutableArray only.
source

pub fn removeAllObjects(&mut self)

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn removeObject_inRange( &mut self, an_object: &ObjectType, range: NSRange )

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn removeObject(&mut self, an_object: &ObjectType)

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn removeObjectIdenticalTo_inRange( &mut self, an_object: &ObjectType, range: NSRange )

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn removeObjectIdenticalTo(&mut self, an_object: &ObjectType)

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn removeObjectsFromIndices_numIndices( &mut self, indices: NonNull<NSUInteger>, cnt: NSUInteger )

👎Deprecated: Not supported
Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn removeObjectsInArray(&mut self, other_array: &NSArray<ObjectType>)

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn removeObjectsInRange(&mut self, range: NSRange)

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn replaceObjectsInRange_withObjectsFromArray_range( &mut self, range: NSRange, other_array: &NSArray<ObjectType>, other_range: NSRange )

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn replaceObjectsInRange_withObjectsFromArray( &mut self, range: NSRange, other_array: &NSArray<ObjectType> )

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn setArray(&mut self, other_array: &NSArray<ObjectType>)

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn sortUsingFunction_context( &mut self, compare: unsafe extern "C" fn(_: NonNull<ObjectType>, _: NonNull<ObjectType>, _: *mut c_void) -> NSInteger, context: *mut c_void )

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn sortUsingSelector(&mut self, comparator: Sel)

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn insertObjects_atIndexes( &mut self, objects: &NSArray<ObjectType>, indexes: &NSIndexSet )

Available on crate features Foundation_NSMutableArray and Foundation_NSIndexSet only.
source

pub unsafe fn removeObjectsAtIndexes(&mut self, indexes: &NSIndexSet)

Available on crate features Foundation_NSMutableArray and Foundation_NSIndexSet only.
source

pub unsafe fn replaceObjectsAtIndexes_withObjects( &mut self, indexes: &NSIndexSet, objects: &NSArray<ObjectType> )

Available on crate features Foundation_NSMutableArray and Foundation_NSIndexSet only.
source

pub unsafe fn setObject_atIndexedSubscript( &mut self, obj: &ObjectType, idx: NSUInteger )

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn sortUsingComparator(&mut self, cmptr: NSComparator)

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn sortWithOptions_usingComparator( &mut self, opts: NSSortOptions, cmptr: NSComparator )

Available on crate feature Foundation_NSMutableArray only.
source

impl<ObjectType: Message> NSMutableArray<ObjectType>

NSMutableArrayCreation

source

pub unsafe fn arrayWithCapacity(num_items: NSUInteger) -> Id<Self>

Available on crate feature Foundation_NSMutableArray only.
source

pub unsafe fn arrayWithContentsOfFile( path: &NSString ) -> Option<Id<NSMutableArray<ObjectType>>>

Available on crate features Foundation_NSMutableArray and Foundation_NSString only.
source

pub unsafe fn arrayWithContentsOfURL( url: &NSURL ) -> Option<Id<NSMutableArray<ObjectType>>>

Available on crate features Foundation_NSMutableArray and Foundation_NSURL only.
source

pub unsafe fn initWithContentsOfFile( this: Option<Allocated<Self>>, path: &NSString ) -> Option<Id<NSMutableArray<ObjectType>>>

Available on crate features Foundation_NSMutableArray and Foundation_NSString only.
source

pub unsafe fn initWithContentsOfURL( this: Option<Allocated<Self>>, url: &NSURL ) -> Option<Id<NSMutableArray<ObjectType>>>

Available on crate features Foundation_NSMutableArray and Foundation_NSURL only.
source

impl<ObjectType: Message> NSMutableArray<ObjectType>

NSMutableArrayDiffing

source

pub unsafe fn applyDifference( &mut self, difference: &NSOrderedCollectionDifference<ObjectType> )

Available on crate features Foundation_NSMutableArray and Foundation_NSOrderedCollectionDifference only.
source

impl<ObjectType: Message> NSMutableArray<ObjectType>

NSPredicateSupport

source

pub unsafe fn filterUsingPredicate(&mut self, predicate: &NSPredicate)

Available on crate features Foundation_NSMutableArray and Foundation_NSPredicate only.
source

impl<ObjectType: Message> NSMutableArray<ObjectType>

NSSortDescriptorSorting

source

pub unsafe fn sortUsingDescriptors( &mut self, sort_descriptors: &NSArray<NSSortDescriptor> )

Available on crate features Foundation_NSMutableArray and Foundation_NSSortDescriptor only.

Methods from Deref<Target = NSArray<ObjectType>>

source

pub fn to_vec(&self) -> Vec<&T>

source

pub fn to_vec_retained(&self) -> Vec<Id<T>>where T: IsIdCloneable,

source

pub fn len(&self) -> usize

source

pub fn is_empty(&self) -> bool

source

pub fn get(&self, index: usize) -> Option<&T>

source

pub fn get_retained(&self, index: usize) -> Option<Id<T>>where T: IsIdCloneable,

source

pub fn get_mut(&mut self, index: usize) -> Option<&mut T>where T: IsMutable,

source

pub fn first(&self) -> Option<&T>

source

pub fn first_retained(&self) -> Option<Id<T>>where T: IsIdCloneable,

source

pub fn first_mut(&mut self) -> Option<&mut T>where T: IsMutable,

source

pub fn last(&self) -> Option<&T>

source

pub fn last_retained(&self) -> Option<Id<T>>where T: IsIdCloneable,

source

pub fn last_mut(&mut self) -> Option<&mut T>where T: IsMutable,

source

pub fn objects_in_range(&self, range: Range<usize>) -> Option<Vec<&T>>

source

pub fn iter(&self) -> Iter<'_, T>

source

pub fn iter_mut(&mut self) -> IterMut<'_, T> where T: IsMutable,

source

pub fn iter_retained(&self) -> IterRetained<'_, T> where T: IsIdCloneable,

source

pub fn count(&self) -> NSUInteger

source

pub unsafe fn objectAtIndex(&self, index: NSUInteger) -> Id<ObjectType>

source

pub unsafe fn arrayByAddingObject( &self, an_object: &ObjectType ) -> Id<NSArray<ObjectType>>

source

pub unsafe fn arrayByAddingObjectsFromArray( &self, other_array: &NSArray<ObjectType> ) -> Id<NSArray<ObjectType>>

source

pub unsafe fn componentsJoinedByString( &self, separator: &NSString ) -> Id<NSString>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn containsObject(&self, an_object: &ObjectType) -> bool

source

pub unsafe fn description(&self) -> Id<NSString>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn descriptionWithLocale( &self, locale: Option<&AnyObject> ) -> Id<NSString>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn descriptionWithLocale_indent( &self, locale: Option<&AnyObject>, level: NSUInteger ) -> Id<NSString>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn firstObjectCommonWithArray( &self, other_array: &NSArray<ObjectType> ) -> Option<Id<ObjectType>>

source

pub unsafe fn getObjects_range( &self, objects: NonNull<NonNull<ObjectType>>, range: NSRange )

source

pub unsafe fn indexOfObject(&self, an_object: &ObjectType) -> NSUInteger

source

pub unsafe fn indexOfObject_inRange( &self, an_object: &ObjectType, range: NSRange ) -> NSUInteger

source

pub unsafe fn indexOfObjectIdenticalTo( &self, an_object: &ObjectType ) -> NSUInteger

source

pub unsafe fn indexOfObjectIdenticalTo_inRange( &self, an_object: &ObjectType, range: NSRange ) -> NSUInteger

source

pub unsafe fn isEqualToArray(&self, other_array: &NSArray<ObjectType>) -> bool

source

pub unsafe fn firstObject(&self) -> Option<Id<ObjectType>>

source

pub unsafe fn lastObject(&self) -> Option<Id<ObjectType>>

source

pub unsafe fn objectEnumerator(&self) -> Id<NSEnumerator<ObjectType>>

Available on crate feature Foundation_NSEnumerator only.
source

pub unsafe fn reverseObjectEnumerator(&self) -> Id<NSEnumerator<ObjectType>>

Available on crate feature Foundation_NSEnumerator only.
source

pub unsafe fn sortedArrayHint(&self) -> Id<NSData>

Available on crate feature Foundation_NSData only.
source

pub unsafe fn sortedArrayUsingFunction_context( &self, comparator: unsafe extern "C" fn(_: NonNull<ObjectType>, _: NonNull<ObjectType>, _: *mut c_void) -> NSInteger, context: *mut c_void ) -> Id<NSArray<ObjectType>>

source

pub unsafe fn sortedArrayUsingFunction_context_hint( &self, comparator: unsafe extern "C" fn(_: NonNull<ObjectType>, _: NonNull<ObjectType>, _: *mut c_void) -> NSInteger, context: *mut c_void, hint: Option<&NSData> ) -> Id<NSArray<ObjectType>>

Available on crate feature Foundation_NSData only.
source

pub unsafe fn sortedArrayUsingSelector( &self, comparator: Sel ) -> Id<NSArray<ObjectType>>

source

pub unsafe fn subarrayWithRange( &self, range: NSRange ) -> Id<NSArray<ObjectType>>

source

pub unsafe fn writeToURL_error(&self, url: &NSURL) -> Result<(), Id<NSError>>

Available on crate features Foundation_NSError and Foundation_NSURL only.
source

pub unsafe fn makeObjectsPerformSelector(&self, a_selector: Sel)

source

pub unsafe fn makeObjectsPerformSelector_withObject( &self, a_selector: Sel, argument: Option<&AnyObject> )

source

pub unsafe fn objectsAtIndexes( &self, indexes: &NSIndexSet ) -> Id<NSArray<ObjectType>>

Available on crate feature Foundation_NSIndexSet only.
source

pub unsafe fn objectAtIndexedSubscript(&self, idx: NSUInteger) -> Id<ObjectType>

source

pub unsafe fn enumerateObjectsUsingBlock( &self, block: &Block<(NonNull<ObjectType>, NSUInteger, NonNull<Bool>), ()> )

source

pub unsafe fn enumerateObjectsWithOptions_usingBlock( &self, opts: NSEnumerationOptions, block: &Block<(NonNull<ObjectType>, NSUInteger, NonNull<Bool>), ()> )

source

pub unsafe fn enumerateObjectsAtIndexes_options_usingBlock( &self, s: &NSIndexSet, opts: NSEnumerationOptions, block: &Block<(NonNull<ObjectType>, NSUInteger, NonNull<Bool>), ()> )

Available on crate feature Foundation_NSIndexSet only.
source

pub unsafe fn indexOfObjectPassingTest( &self, predicate: &Block<(NonNull<ObjectType>, NSUInteger, NonNull<Bool>), Bool> ) -> NSUInteger

source

pub unsafe fn indexOfObjectWithOptions_passingTest( &self, opts: NSEnumerationOptions, predicate: &Block<(NonNull<ObjectType>, NSUInteger, NonNull<Bool>), Bool> ) -> NSUInteger

source

pub unsafe fn indexOfObjectAtIndexes_options_passingTest( &self, s: &NSIndexSet, opts: NSEnumerationOptions, predicate: &Block<(NonNull<ObjectType>, NSUInteger, NonNull<Bool>), Bool> ) -> NSUInteger

Available on crate feature Foundation_NSIndexSet only.
source

pub unsafe fn indexesOfObjectsPassingTest( &self, predicate: &Block<(NonNull<ObjectType>, NSUInteger, NonNull<Bool>), Bool> ) -> Id<NSIndexSet>

Available on crate feature Foundation_NSIndexSet only.
source

pub unsafe fn indexesOfObjectsWithOptions_passingTest( &self, opts: NSEnumerationOptions, predicate: &Block<(NonNull<ObjectType>, NSUInteger, NonNull<Bool>), Bool> ) -> Id<NSIndexSet>

Available on crate feature Foundation_NSIndexSet only.
source

pub unsafe fn indexesOfObjectsAtIndexes_options_passingTest( &self, s: &NSIndexSet, opts: NSEnumerationOptions, predicate: &Block<(NonNull<ObjectType>, NSUInteger, NonNull<Bool>), Bool> ) -> Id<NSIndexSet>

Available on crate feature Foundation_NSIndexSet only.
source

pub unsafe fn sortedArrayUsingComparator( &self, cmptr: NSComparator ) -> Id<NSArray<ObjectType>>

source

pub unsafe fn sortedArrayWithOptions_usingComparator( &self, opts: NSSortOptions, cmptr: NSComparator ) -> Id<NSArray<ObjectType>>

source

pub unsafe fn indexOfObject_inSortedRange_options_usingComparator( &self, obj: &ObjectType, r: NSRange, opts: NSBinarySearchingOptions, cmp: NSComparator ) -> NSUInteger

source

pub unsafe fn differenceFromArray_withOptions_usingEquivalenceTest( &self, other: &NSArray<ObjectType>, options: NSOrderedCollectionDifferenceCalculationOptions, block: &Block<(NonNull<ObjectType>, NonNull<ObjectType>), Bool> ) -> Id<NSOrderedCollectionDifference<ObjectType>>

Available on crate feature Foundation_NSOrderedCollectionDifference only.
source

pub unsafe fn differenceFromArray_withOptions( &self, other: &NSArray<ObjectType>, options: NSOrderedCollectionDifferenceCalculationOptions ) -> Id<NSOrderedCollectionDifference<ObjectType>>

Available on crate feature Foundation_NSOrderedCollectionDifference only.
source

pub unsafe fn differenceFromArray( &self, other: &NSArray<ObjectType> ) -> Id<NSOrderedCollectionDifference<ObjectType>>

Available on crate feature Foundation_NSOrderedCollectionDifference only.
source

pub unsafe fn arrayByApplyingDifference( &self, difference: &NSOrderedCollectionDifference<ObjectType> ) -> Option<Id<NSArray<ObjectType>>>

Available on crate feature Foundation_NSOrderedCollectionDifference only.
source

pub unsafe fn getObjects(&self, objects: NonNull<NonNull<ObjectType>>)

👎Deprecated: Use -getObjects:range: instead
source

pub unsafe fn writeToFile_atomically( &self, path: &NSString, use_auxiliary_file: bool ) -> bool

👎Deprecated
Available on crate feature Foundation_NSString only.
source

pub unsafe fn writeToURL_atomically( &self, url: &NSURL, atomically: bool ) -> bool

👎Deprecated
Available on crate feature Foundation_NSURL only.
source

pub unsafe fn valueForKey(&self, key: &NSString) -> Id<AnyObject>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn setValue_forKey(&self, value: Option<&AnyObject>, key: &NSString)

Available on crate feature Foundation_NSString only.
source

pub unsafe fn addObserver_toObjectsAtIndexes_forKeyPath_options_context( &self, observer: &NSObject, indexes: &NSIndexSet, key_path: &NSString, options: NSKeyValueObservingOptions, context: *mut c_void )

Available on crate features Foundation_NSIndexSet and Foundation_NSString only.
source

pub unsafe fn removeObserver_fromObjectsAtIndexes_forKeyPath_context( &self, observer: &NSObject, indexes: &NSIndexSet, key_path: &NSString, context: *mut c_void )

Available on crate features Foundation_NSIndexSet and Foundation_NSString only.
source

pub unsafe fn removeObserver_fromObjectsAtIndexes_forKeyPath( &self, observer: &NSObject, indexes: &NSIndexSet, key_path: &NSString )

Available on crate features Foundation_NSIndexSet and Foundation_NSString only.
source

pub unsafe fn addObserver_forKeyPath_options_context( &self, observer: &NSObject, key_path: &NSString, options: NSKeyValueObservingOptions, context: *mut c_void )

Available on crate feature Foundation_NSString only.
source

pub unsafe fn removeObserver_forKeyPath_context( &self, observer: &NSObject, key_path: &NSString, context: *mut c_void )

Available on crate feature Foundation_NSString only.
source

pub unsafe fn removeObserver_forKeyPath( &self, observer: &NSObject, key_path: &NSString )

Available on crate feature Foundation_NSString only.
source

pub unsafe fn pathsMatchingExtensions( &self, filter_types: &NSArray<NSString> ) -> Id<NSArray<NSString>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn filteredArrayUsingPredicate( &self, predicate: &NSPredicate ) -> Id<NSArray<ObjectType>>

Available on crate feature Foundation_NSPredicate only.
source

pub unsafe fn sortedArrayUsingDescriptors( &self, sort_descriptors: &NSArray<NSSortDescriptor> ) -> Id<NSArray<ObjectType>>

Available on crate feature Foundation_NSSortDescriptor only.

Methods from Deref<Target = AnyObject>

source

pub fn class(&self) -> &AnyClass

Dynamically find the class of this object.

source

pub unsafe fn ivar_ptr<T>(&self, name: &str) -> *mut Twhere T: Encode,

Returns a pointer to the instance variable / ivar with the given name.

This is similar to UnsafeCell::get, see that for more information on what is and isn’t safe to do.

Usually you will have defined the instance variable yourself with ClassBuilder::add_ivar, the type of the ivar T must match the type used in that.

Attempting to access or modify private implementation details of a class that you do no control using this is not supported, and may invoke undefined behaviour.

Library implementors are strongly encouraged to expose a safe interface to the ivar.

Panics

May panic if the object has no ivar with the given name. May also panic if the type encoding of the ivar differs from the type encoding of T.

This should purely seen as help while debugging and is not guaranteed (e.g. it may be disabled when debug_assertions are off).

Safety

The object must have an instance variable with the given name, and it must be of type T. Any invariants that the object have assumed about the value of the instance variable must not be violated.

No thread syncronization is done on accesses to the variable, so you must ensure that any access to the returned pointer do not cause data races, and that Rust’s mutability rules are not otherwise violated.

source

pub unsafe fn ivar<T>(&self, name: &str) -> &Twhere T: Encode,

Returns a reference to the instance variable with the given name.

See AnyObject::ivar_ptr for more information, including on when this panics.

Safety

The object must have an instance variable with the given name, and it must be of type T.

No thread syncronization is done, so you must ensure that no other thread is concurrently mutating the variable. This requirement can be considered upheld if all mutation happens through AnyObject::ivar_mut (since that takes &mut self).

source

pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere T: Encode,

👎Deprecated: Use AnyObject::ivar instead.
source

pub unsafe fn ivar_mut<T>(&mut self, name: &str) -> &mut Twhere T: Encode,

Returns a mutable reference to the ivar with the given name.

See AnyObject::ivar_ptr for more information, including on when this panics.

Safety

The object must have an instance variable with the given name, and it must be of type T.

This access happens through &mut self, which means we know it to be the only reference, hence you do not need to do any work to ensure that data races do not happen.

source

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere T: Encode,

👎Deprecated: Use AnyObject::ivar_mut instead.
source

pub unsafe fn set_ivar<T>(&mut self, name: &str, value: T)where T: Encode,

Sets the value of the ivar with the given name.

This is a shorthand for AnyObject::ivar_mut, see that for more information.

Safety

Same as AnyObject::ivar_mut.