Struct icrate::Foundation::NSNumber

source ·
#[repr(C)]
pub struct NSNumber { /* private fields */ }
Available on crate features Foundation and Foundation_NSNumber only.

Implementations

source

impl NSNumber

This impl block contains no items.

CKRecordValue

source

impl NSNumber

This impl block contains no items.

NSFetchedResultSupport

source

impl NSNumber

Creation methods.

source

pub fn new_bool(val: bool) -> Id<Self>

source

pub fn new_i8(val: i8) -> Id<Self>

source

pub fn new_u8(val: u8) -> Id<Self>

source

pub fn new_i16(val: i16) -> Id<Self>

source

pub fn new_u16(val: u16) -> Id<Self>

source

pub fn new_i32(val: i32) -> Id<Self>

source

pub fn new_u32(val: u32) -> Id<Self>

source

pub fn new_i64(val: i64) -> Id<Self>

source

pub fn new_u64(val: u64) -> Id<Self>

source

pub fn new_isize(val: isize) -> Id<Self>

source

pub fn new_usize(val: usize) -> Id<Self>

source

pub fn new_f32(val: f32) -> Id<Self>

source

pub fn new_f64(val: f64) -> Id<Self>

source

pub fn new_cgfloat(val: CGFloat) -> Id<Self>

source

impl NSNumber

Getter methods.

source

pub fn as_bool(&self) -> bool

source

pub fn as_i8(&self) -> i8

source

pub fn as_u8(&self) -> u8

source

pub fn as_i16(&self) -> i16

source

pub fn as_u16(&self) -> u16

source

pub fn as_i32(&self) -> i32

source

pub fn as_u32(&self) -> u32

source

pub fn as_i64(&self) -> i64

source

pub fn as_u64(&self) -> u64

source

pub fn as_isize(&self) -> isize

source

pub fn as_usize(&self) -> usize

source

pub fn as_f32(&self) -> f32

source

pub fn as_f64(&self) -> f64

source

pub fn as_cgfloat(&self) -> CGFloat

source

pub fn encoding(&self) -> Encoding

The Objective-C encoding of this NSNumber.

This is guaranteed to return one of:

Examples

Convert an NSNumber to/from an enumeration describing the different number properties.

use icrate::Foundation::NSNumber;
use icrate::objc2::Encoding;
use icrate::objc2::rc::Id;

// Note: `bool` would convert to either `Signed` or `Unsigned`,
// depending on platform
#[derive(Copy, Clone)]
pub enum Number {
    Signed(i64),
    Unsigned(u64),
    Floating(f64),
}

impl Number {
    fn into_nsnumber(self) -> Id<NSNumber> {
        match self {
            Self::Signed(val) => NSNumber::new_i64(val),
            Self::Unsigned(val) => NSNumber::new_u64(val),
            Self::Floating(val) => NSNumber::new_f64(val),
        }
    }
}

impl From<&NSNumber> for Number {
    fn from(n: &NSNumber) -> Self {
        match n.encoding() {
            Encoding::Char
            | Encoding::Short
            | Encoding::Int
            | Encoding::Long
            | Encoding::LongLong => Self::Signed(n.as_i64()),
            Encoding::UChar
            | Encoding::UShort
            | Encoding::UInt
            | Encoding::ULong
            | Encoding::ULongLong => Self::Unsigned(n.as_u64()),
            Encoding::Float
            | Encoding::Double => Self::Floating(n.as_f64()),
            _ => unreachable!(),
        }
    }
}
source

impl NSNumber

NSDecimalNumberExtensions

source

pub unsafe fn decimalValue(&self) -> NSDecimal

source

impl NSNumber

source

pub unsafe fn initWithCoder( this: Option<Allocated<Self>>, coder: &NSCoder ) -> Option<Id<Self>>

Available on crate feature Foundation_NSCoder only.
source

pub fn initWithChar( this: Option<Allocated<Self>>, value: c_char ) -> Id<NSNumber>

source

pub fn initWithUnsignedChar( this: Option<Allocated<Self>>, value: c_uchar ) -> Id<NSNumber>

source

pub fn initWithShort( this: Option<Allocated<Self>>, value: c_short ) -> Id<NSNumber>

source

pub fn initWithUnsignedShort( this: Option<Allocated<Self>>, value: c_ushort ) -> Id<NSNumber>

source

pub fn initWithInt(this: Option<Allocated<Self>>, value: c_int) -> Id<NSNumber>

source

pub fn initWithUnsignedInt( this: Option<Allocated<Self>>, value: c_uint ) -> Id<NSNumber>

source

pub fn initWithLong( this: Option<Allocated<Self>>, value: c_long ) -> Id<NSNumber>

source

pub fn initWithUnsignedLong( this: Option<Allocated<Self>>, value: c_ulong ) -> Id<NSNumber>

source

pub fn initWithLongLong( this: Option<Allocated<Self>>, value: c_longlong ) -> Id<NSNumber>

source

pub fn initWithUnsignedLongLong( this: Option<Allocated<Self>>, value: c_ulonglong ) -> Id<NSNumber>

source

pub fn initWithFloat( this: Option<Allocated<Self>>, value: c_float ) -> Id<NSNumber>

source

pub fn initWithDouble( this: Option<Allocated<Self>>, value: c_double ) -> Id<NSNumber>

source

pub fn initWithBool(this: Option<Allocated<Self>>, value: bool) -> Id<NSNumber>

source

pub fn initWithInteger( this: Option<Allocated<Self>>, value: NSInteger ) -> Id<NSNumber>

source

pub fn initWithUnsignedInteger( this: Option<Allocated<Self>>, value: NSUInteger ) -> Id<NSNumber>

source

pub fn charValue(&self) -> c_char

source

pub fn unsignedCharValue(&self) -> c_uchar

source

pub fn shortValue(&self) -> c_short

source

pub fn unsignedShortValue(&self) -> c_ushort

source

pub fn intValue(&self) -> c_int

source

pub fn unsignedIntValue(&self) -> c_uint

source

pub fn longValue(&self) -> c_long

source

pub fn unsignedLongValue(&self) -> c_ulong

source

pub fn longLongValue(&self) -> c_longlong

source

pub fn unsignedLongLongValue(&self) -> c_ulonglong

source

pub fn floatValue(&self) -> c_float

source

pub fn doubleValue(&self) -> c_double

source

pub fn boolValue(&self) -> bool

source

pub fn integerValue(&self) -> NSInteger

source

pub fn unsignedIntegerValue(&self) -> NSUInteger

source

pub fn stringValue(&self) -> Id<NSString>

Available on crate feature Foundation_NSString only.
source

pub fn compare(&self, other_number: &NSNumber) -> NSComparisonResult

source

pub fn isEqualToNumber(&self, number: &NSNumber) -> bool

source

pub unsafe fn descriptionWithLocale( &self, locale: Option<&AnyObject> ) -> Id<NSString>

Available on crate feature Foundation_NSString only.
source

impl NSNumber

Methods declared on superclass NSValue

source

pub unsafe fn initWithBytes_objCType( this: Option<Allocated<Self>>, value: NonNull<c_void>, type: NonNull<c_char> ) -> Id<Self>

source

impl NSNumber

NSNumberCreation

Methods from Deref<Target = NSValue>

source

pub unsafe fn CATransform3DValue(&self) -> CATransform3D

Available on crate features CoreAnimation and Foundation_NSValue only.
source

pub unsafe fn get<T: 'static + Copy + Encode>(&self) -> T

Available on crate feature Foundation_NSValue only.

Retrieve the data contained in the NSValue.

Note that this is broken on GNUStep for some types, see gnustep/libs-base#216.

Safety

The type of T must be what the NSValue actually stores, and any safety invariants that the value has must be upheld.

Note that it may be enough, although is not always, to check whether contains_encoding returns true. For example, NonNull<T> have the same encoding as *const T, but NonNull<T> is clearly not safe to return from this function even if you’ve checked the encoding beforehand.

Examples

Store a pointer in NSValue, and retrieve it again afterwards.

use std::ffi::c_void;
use std::ptr;
use icrate::Foundation::NSValue;

let val = NSValue::new::<*const c_void>(ptr::null());
// SAFETY: The value was just created with a pointer
let res = unsafe { val.get::<*const c_void>() };
assert!(res.is_null());
source

pub fn get_range(&self) -> Option<NSRange>

Available on crate feature Foundation_NSValue only.
source

pub fn get_point(&self) -> Option<NSPoint>

Available on crate feature Foundation_NSValue only.
source

pub fn get_size(&self) -> Option<NSSize>

Available on crate feature Foundation_NSValue only.
source

pub fn get_rect(&self) -> Option<NSRect>

Available on crate feature Foundation_NSValue only.
source

pub fn encoding(&self) -> Option<&str>

Available on crate feature Foundation_NSValue only.
source

pub fn contains_encoding<T: 'static + Copy + Encode>(&self) -> bool

Available on crate feature Foundation_NSValue only.
source

pub unsafe fn pointValue(&self) -> NSPoint

Available on crate feature Foundation_NSValue only.
source

pub unsafe fn sizeValue(&self) -> NSSize

Available on crate feature Foundation_NSValue only.
source

pub unsafe fn rectValue(&self) -> NSRect

Available on crate feature Foundation_NSValue only.
source

pub unsafe fn edgeInsetsValue(&self) -> NSEdgeInsets

Available on crate feature Foundation_NSValue only.
source

pub unsafe fn rangeValue(&self) -> NSRange

Available on crate feature Foundation_NSValue only.
source

pub unsafe fn getValue_size(&self, value: NonNull<c_void>, size: NSUInteger)

Available on crate feature Foundation_NSValue only.
source

pub fn objCType(&self) -> NonNull<c_char>

Available on crate feature Foundation_NSValue only.
source

pub unsafe fn nonretainedObjectValue(&self) -> Option<Id<AnyObject>>

Available on crate feature Foundation_NSValue only.
source

pub unsafe fn pointerValue(&self) -> *mut c_void

Available on crate feature Foundation_NSValue only.
source

pub fn isEqualToValue(&self, value: &NSValue) -> bool

Available on crate feature Foundation_NSValue only.
source

pub unsafe fn getValue(&self, value: NonNull<c_void>)

👎Deprecated
Available on crate feature Foundation_NSValue only.
source

pub unsafe fn MKCoordinateValue(&self) -> CLLocationCoordinate2D

Available on crate features MapKit and Foundation_NSValue only.
source

pub unsafe fn MKCoordinateSpanValue(&self) -> MKCoordinateSpan

Available on crate features MapKit and Foundation_NSValue only.

Methods from Deref<Target = AnyObject>

source

pub fn class(&self) -> &AnyClass

Dynamically find the class of this object.

source

pub unsafe fn ivar_ptr<T>(&self, name: &str) -> *mut Twhere T: Encode,

Returns a pointer to the instance variable / ivar with the given name.

This is similar to UnsafeCell::get, see that for more information on what is and isn’t safe to do.

Usually you will have defined the instance variable yourself with ClassBuilder::add_ivar, the type of the ivar T must match the type used in that.

Attempting to access or modify private implementation details of a class that you do no control using this is not supported, and may invoke undefined behaviour.

Library implementors are strongly encouraged to expose a safe interface to the ivar.

Panics

May panic if the object has no ivar with the given name. May also panic if the type encoding of the ivar differs from the type encoding of T.

This should purely seen as help while debugging and is not guaranteed (e.g. it may be disabled when debug_assertions are off).

Safety

The object must have an instance variable with the given name, and it must be of type T. Any invariants that the object have assumed about the value of the instance variable must not be violated.

No thread syncronization is done on accesses to the variable, so you must ensure that any access to the returned pointer do not cause data races, and that Rust’s mutability rules are not otherwise violated.

source

pub unsafe fn ivar<T>(&self, name: &str) -> &Twhere T: Encode,

Returns a reference to the instance variable with the given name.

See AnyObject::ivar_ptr for more information, including on when this panics.

Safety

The object must have an instance variable with the given name, and it must be of type T.

No thread syncronization is done, so you must ensure that no other thread is concurrently mutating the variable. This requirement can be considered upheld if all mutation happens through AnyObject::ivar_mut (since that takes &mut self).

source

pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere T: Encode,

👎Deprecated: Use AnyObject::ivar instead.
source

pub unsafe fn ivar_mut<T>(&mut self, name: &str) -> &mut Twhere T: Encode,

Returns a mutable reference to the ivar with the given name.

See AnyObject::ivar_ptr for more information, including on when this panics.

Safety

The object must have an instance variable with the given name, and it must be of type T.

This access happens through &mut self, which means we know it to be the only reference, hence you do not need to do any work to ensure that data races do not happen.

source

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere T: Encode,

👎Deprecated: Use AnyObject::ivar_mut instead.
source

pub unsafe fn set_ivar<T>(&mut self, name: &str, value: T)where T: Encode,

Sets the value of the ivar with the given name.

This is a shorthand for AnyObject::ivar_mut, see that for more information.

Safety

Same as AnyObject::ivar_mut.