#[repr(C)]pub struct NSPredicate { /* private fields */ }👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate features
Foundation and Foundation_NSPredicate only.Implementations
Sourceimpl NSPredicate
impl NSPredicate
pub unsafe fn predicateWithFormat_argumentArray( predicate_format: &NSString, arguments: Option<&NSArray>, ) -> Id<NSPredicate>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate features
Foundation_NSArray and Foundation_NSString only.pub unsafe fn predicateFromMetadataQueryString( query_string: &NSString, ) -> Option<Id<NSPredicate>>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate feature
Foundation_NSString only.pub unsafe fn predicateWithValue(value: bool) -> Id<NSPredicate>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationpub unsafe fn predicateWithBlock( block: &Block<(*mut AnyObject, *mut NSDictionary<NSString, AnyObject>), Bool>, ) -> Id<NSPredicate>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate features
Foundation_NSDictionary and Foundation_NSString only.pub unsafe fn predicateFormat(&self) -> Id<NSString>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate feature
Foundation_NSString only.pub unsafe fn predicateWithSubstitutionVariables( &self, variables: &NSDictionary<NSString, AnyObject>, ) -> Id<Self>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate features
Foundation_NSDictionary and Foundation_NSString only.pub unsafe fn evaluateWithObject(&self, object: Option<&AnyObject>) -> bool
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationpub unsafe fn evaluateWithObject_substitutionVariables( &self, object: Option<&AnyObject>, bindings: Option<&NSDictionary<NSString, AnyObject>>, ) -> bool
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate features
Foundation_NSDictionary and Foundation_NSString only.pub unsafe fn allowEvaluation(&self)
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationMethods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Available on crate feature AuthenticationServices only.
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
AuthenticationServices only.Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.