Struct icrate::Foundation::NSRange

source ·
#[repr(C)]
pub struct NSRange { pub location: NSUInteger, pub length: NSUInteger, }
Available on crate feature Foundation only.
Fields

location: NSUInteger

The lower bound of the range (inclusive).

length: NSUInteger

The number of items in the range, starting from location.

Implementations

source

impl NSRange

source

pub const fn new(location: usize, length: usize) -> Self

Create a new range with the given values.

Examples
use icrate::Foundation::NSRange;
assert_eq!(NSRange::new(3, 2), NSRange::from(3..5));
source

pub fn is_empty(&self) -> bool

Returns true if the range contains no items.

Examples
use icrate::Foundation::NSRange;

assert!(!NSRange::from(3..5).is_empty());
assert!( NSRange::from(3..3).is_empty());
source

pub fn contains(&self, index: usize) -> bool

Returns true if the index is within the range.

Examples
use icrate::Foundation::NSRange;

assert!(!NSRange::from(3..5).contains(2));
assert!( NSRange::from(3..5).contains(3));
assert!( NSRange::from(3..5).contains(4));
assert!(!NSRange::from(3..5).contains(5));

assert!(!NSRange::from(3..3).contains(3));
source

pub fn end(&self) -> usize

Returns the upper bound of the range (exclusive).