Struct icrate::Foundation::NSURL

source ·
#[repr(C)]
pub struct NSURL { /* private fields */ }
Available on crate features Foundation and Foundation_NSURL only.

Implementations

source

impl NSURL

NSPasteboardSupport

source

pub unsafe fn URLFromPasteboard(paste_board: &NSPasteboard) -> Option<Id<NSURL>>

Available on crate features AppKit and AppKit_NSPasteboard only.
source

pub unsafe fn writeToPasteboard(&self, paste_board: &NSPasteboard)

Available on crate features AppKit and AppKit_NSPasteboard only.
source

impl NSURL

source

pub unsafe fn initWithScheme_host_path( this: Option<Allocated<Self>>, scheme: &NSString, host: Option<&NSString>, path: &NSString ) -> Option<Id<Self>>

👎Deprecated: Use NSURLComponents instead, which lets you create a valid URL with any valid combination of URL components and subcomponents (not just scheme, host and path), and lets you set components and subcomponents with either percent-encoded or un-percent-encoded strings.
Available on crate feature Foundation_NSString only.
source

pub unsafe fn initFileURLWithPath_isDirectory_relativeToURL( this: Option<Allocated<Self>>, path: &NSString, is_dir: bool, base_url: Option<&NSURL> ) -> Id<Self>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn initFileURLWithPath_relativeToURL( this: Option<Allocated<Self>>, path: &NSString, base_url: Option<&NSURL> ) -> Id<Self>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn initFileURLWithPath_isDirectory( this: Option<Allocated<Self>>, path: &NSString, is_dir: bool ) -> Id<Self>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn initFileURLWithPath( this: Option<Allocated<Self>>, path: &NSString ) -> Id<Self>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn fileURLWithPath_isDirectory_relativeToURL( path: &NSString, is_dir: bool, base_url: Option<&NSURL> ) -> Id<NSURL>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn fileURLWithPath_relativeToURL( path: &NSString, base_url: Option<&NSURL> ) -> Id<NSURL>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn fileURLWithPath_isDirectory( path: &NSString, is_dir: bool ) -> Id<NSURL>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn fileURLWithPath(path: &NSString) -> Id<NSURL>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn initFileURLWithFileSystemRepresentation_isDirectory_relativeToURL( this: Option<Allocated<Self>>, path: NonNull<c_char>, is_dir: bool, base_url: Option<&NSURL> ) -> Id<Self>

source

pub unsafe fn fileURLWithFileSystemRepresentation_isDirectory_relativeToURL( path: NonNull<c_char>, is_dir: bool, base_url: Option<&NSURL> ) -> Id<NSURL>

source

pub unsafe fn initWithString( this: Option<Allocated<Self>>, url_string: &NSString ) -> Option<Id<Self>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn initWithString_relativeToURL( this: Option<Allocated<Self>>, url_string: &NSString, base_url: Option<&NSURL> ) -> Option<Id<Self>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn URLWithString(url_string: &NSString) -> Option<Id<Self>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn URLWithString_relativeToURL( url_string: &NSString, base_url: Option<&NSURL> ) -> Option<Id<Self>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn initWithDataRepresentation_relativeToURL( this: Option<Allocated<Self>>, data: &NSData, base_url: Option<&NSURL> ) -> Id<Self>

Available on crate feature Foundation_NSData only.
source

pub unsafe fn URLWithDataRepresentation_relativeToURL( data: &NSData, base_url: Option<&NSURL> ) -> Id<NSURL>

Available on crate feature Foundation_NSData only.
source

pub unsafe fn initAbsoluteURLWithDataRepresentation_relativeToURL( this: Option<Allocated<Self>>, data: &NSData, base_url: Option<&NSURL> ) -> Id<Self>

Available on crate feature Foundation_NSData only.
source

pub unsafe fn absoluteURLWithDataRepresentation_relativeToURL( data: &NSData, base_url: Option<&NSURL> ) -> Id<NSURL>

Available on crate feature Foundation_NSData only.
source

pub unsafe fn dataRepresentation(&self) -> Id<NSData>

Available on crate feature Foundation_NSData only.
source

pub unsafe fn absoluteString(&self) -> Option<Id<NSString>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn relativeString(&self) -> Id<NSString>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn baseURL(&self) -> Option<Id<NSURL>>

source

pub unsafe fn absoluteURL(&self) -> Option<Id<NSURL>>

source

pub unsafe fn scheme(&self) -> Option<Id<NSString>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn resourceSpecifier(&self) -> Option<Id<NSString>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn host(&self) -> Option<Id<NSString>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn port(&self) -> Option<Id<NSNumber>>

Available on crate feature Foundation_NSNumber only.
source

pub unsafe fn user(&self) -> Option<Id<NSString>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn password(&self) -> Option<Id<NSString>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn path(&self) -> Option<Id<NSString>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn fragment(&self) -> Option<Id<NSString>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn parameterString(&self) -> Option<Id<NSString>>

👎Deprecated: The parameterString method is deprecated. Post deprecation for applications linked with or after the macOS 10.15, and for all iOS, watchOS, and tvOS applications, parameterString will always return nil, and the path method will return the complete path including the semicolon separator and params component if the URL string contains them.
Available on crate feature Foundation_NSString only.
source

pub unsafe fn query(&self) -> Option<Id<NSString>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn relativePath(&self) -> Option<Id<NSString>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn hasDirectoryPath(&self) -> bool

source

pub unsafe fn getFileSystemRepresentation_maxLength( &self, buffer: NonNull<c_char>, max_buffer_length: NSUInteger ) -> bool

source

pub unsafe fn fileSystemRepresentation(&self) -> NonNull<c_char>

source

pub unsafe fn isFileURL(&self) -> bool

source

pub unsafe fn standardizedURL(&self) -> Option<Id<NSURL>>

source

pub unsafe fn checkResourceIsReachableAndReturnError( &self ) -> Result<(), Id<NSError>>

Available on crate feature Foundation_NSError only.
source

pub unsafe fn isFileReferenceURL(&self) -> bool

source

pub unsafe fn fileReferenceURL(&self) -> Option<Id<NSURL>>

source

pub unsafe fn filePathURL(&self) -> Option<Id<NSURL>>

source

pub unsafe fn getResourceValue_forKey_error( &self, value: &mut Option<Id<AnyObject>>, key: &NSURLResourceKey ) -> Result<(), Id<NSError>>

Available on crate feature Foundation_NSError only.
source

pub unsafe fn resourceValuesForKeys_error( &self, keys: &NSArray<NSURLResourceKey> ) -> Result<Id<NSDictionary<NSURLResourceKey, AnyObject>>, Id<NSError>>

Available on crate features Foundation_NSArray and Foundation_NSDictionary and Foundation_NSError only.
source

pub unsafe fn setResourceValue_forKey_error( &self, value: Option<&AnyObject>, key: &NSURLResourceKey ) -> Result<(), Id<NSError>>

Available on crate feature Foundation_NSError only.
source

pub unsafe fn setResourceValues_error( &self, keyed_values: &NSDictionary<NSURLResourceKey, AnyObject> ) -> Result<(), Id<NSError>>

Available on crate features Foundation_NSDictionary and Foundation_NSError only.
source

pub unsafe fn removeCachedResourceValueForKey(&self, key: &NSURLResourceKey)

source

pub unsafe fn removeAllCachedResourceValues(&self)

source

pub unsafe fn setTemporaryResourceValue_forKey( &self, value: Option<&AnyObject>, key: &NSURLResourceKey )

source

pub unsafe fn bookmarkDataWithOptions_includingResourceValuesForKeys_relativeToURL_error( &self, options: NSURLBookmarkCreationOptions, keys: Option<&NSArray<NSURLResourceKey>>, relative_url: Option<&NSURL> ) -> Result<Id<NSData>, Id<NSError>>

Available on crate features Foundation_NSArray and Foundation_NSData and Foundation_NSError only.
source

pub unsafe fn initByResolvingBookmarkData_options_relativeToURL_bookmarkDataIsStale_error( this: Option<Allocated<Self>>, bookmark_data: &NSData, options: NSURLBookmarkResolutionOptions, relative_url: Option<&NSURL>, is_stale: *mut Bool ) -> Result<Id<Self>, Id<NSError>>

Available on crate features Foundation_NSData and Foundation_NSError only.
source

pub unsafe fn URLByResolvingBookmarkData_options_relativeToURL_bookmarkDataIsStale_error( bookmark_data: &NSData, options: NSURLBookmarkResolutionOptions, relative_url: Option<&NSURL>, is_stale: *mut Bool ) -> Result<Id<Self>, Id<NSError>>

Available on crate features Foundation_NSData and Foundation_NSError only.
source

pub unsafe fn resourceValuesForKeys_fromBookmarkData( keys: &NSArray<NSURLResourceKey>, bookmark_data: &NSData ) -> Option<Id<NSDictionary<NSURLResourceKey, AnyObject>>>

Available on crate features Foundation_NSArray and Foundation_NSData and Foundation_NSDictionary only.
source

pub unsafe fn writeBookmarkData_toURL_options_error( bookmark_data: &NSData, bookmark_file_url: &NSURL, options: NSURLBookmarkFileCreationOptions ) -> Result<(), Id<NSError>>

Available on crate features Foundation_NSData and Foundation_NSError only.
source

pub unsafe fn bookmarkDataWithContentsOfURL_error( bookmark_file_url: &NSURL ) -> Result<Id<NSData>, Id<NSError>>

Available on crate features Foundation_NSData and Foundation_NSError only.
source

pub unsafe fn URLByResolvingAliasFileAtURL_options_error( url: &NSURL, options: NSURLBookmarkResolutionOptions ) -> Result<Id<Self>, Id<NSError>>

Available on crate feature Foundation_NSError only.
source

pub unsafe fn startAccessingSecurityScopedResource(&self) -> bool

source

pub unsafe fn stopAccessingSecurityScopedResource(&self)

source

impl NSURL

Methods declared on superclass NSObject

source

pub unsafe fn init(this: Option<Allocated<Self>>) -> Id<Self>

source

pub unsafe fn new() -> Id<Self>

source

impl NSURL

NSPromisedItems

source

pub unsafe fn getPromisedItemResourceValue_forKey_error( &self, value: &mut Option<Id<AnyObject>>, key: &NSURLResourceKey ) -> Result<(), Id<NSError>>

Available on crate feature Foundation_NSError only.
source

pub unsafe fn promisedItemResourceValuesForKeys_error( &self, keys: &NSArray<NSURLResourceKey> ) -> Result<Id<NSDictionary<NSURLResourceKey, AnyObject>>, Id<NSError>>

Available on crate features Foundation_NSArray and Foundation_NSDictionary and Foundation_NSError only.
source

pub unsafe fn checkPromisedItemIsReachableAndReturnError( &self ) -> Result<(), Id<NSError>>

Available on crate feature Foundation_NSError only.
source

impl NSURL

This impl block contains no items.

NSItemProvider

source

impl NSURL

NSURLPathUtilities

source

pub unsafe fn fileURLWithPathComponents( components: &NSArray<NSString> ) -> Option<Id<NSURL>>

Available on crate features Foundation_NSArray and Foundation_NSString only.
source

pub unsafe fn pathComponents(&self) -> Option<Id<NSArray<NSString>>>

Available on crate features Foundation_NSArray and Foundation_NSString only.
source

pub unsafe fn lastPathComponent(&self) -> Option<Id<NSString>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn pathExtension(&self) -> Option<Id<NSString>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn URLByAppendingPathComponent( &self, path_component: &NSString ) -> Option<Id<NSURL>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn URLByAppendingPathComponent_isDirectory( &self, path_component: &NSString, is_directory: bool ) -> Option<Id<NSURL>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn URLByDeletingLastPathComponent(&self) -> Option<Id<NSURL>>

source

pub unsafe fn URLByAppendingPathExtension( &self, path_extension: &NSString ) -> Option<Id<NSURL>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn URLByDeletingPathExtension(&self) -> Option<Id<NSURL>>

source

pub unsafe fn URLByStandardizingPath(&self) -> Option<Id<NSURL>>

source

pub unsafe fn URLByResolvingSymlinksInPath(&self) -> Option<Id<NSURL>>

source

impl NSURL

NSURLLoading

source

pub unsafe fn resourceDataUsingCache( &self, should_use_cache: bool ) -> Option<Id<NSData>>

👎Deprecated: Use NSURLConnection instead
Available on crate feature Foundation_NSData only.
source

pub unsafe fn loadResourceDataNotifyingClient_usingCache( &self, client: &AnyObject, should_use_cache: bool )

👎Deprecated: Use NSURLConnection instead
source

pub unsafe fn propertyForKey( &self, property_key: &NSString ) -> Option<Id<AnyObject>>

👎Deprecated: Use NSURLConnection instead
Available on crate feature Foundation_NSString only.
source

pub unsafe fn setResourceData(&self, data: &NSData) -> bool

👎Deprecated: Use NSURLConnection instead
Available on crate feature Foundation_NSData only.
source

pub unsafe fn setProperty_forKey( &self, property: &AnyObject, property_key: &NSString ) -> bool

👎Deprecated: Use NSURLConnection instead
Available on crate feature Foundation_NSString only.
source

pub unsafe fn URLHandleUsingCache( &self, should_use_cache: bool ) -> Option<Id<NSURLHandle>>

👎Deprecated: Use NSURLConnection instead
Available on crate feature Foundation_NSURLHandle only.
source

impl NSURL

UTAdditions

source

pub unsafe fn URLByAppendingPathComponent_conformingToType( &self, partial_name: &NSString, content_type: &UTType ) -> Id<NSURL>

Available on crate features UniformTypeIdentifiers and Foundation_NSString and UniformTypeIdentifiers_UTType only.
source

pub unsafe fn URLByAppendingPathExtensionForType( &self, content_type: &UTType ) -> Id<NSURL>

Available on crate features UniformTypeIdentifiers and UniformTypeIdentifiers_UTType only.

Methods from Deref<Target = AnyObject>

source

pub fn class(&self) -> &AnyClass

Dynamically find the class of this object.

source

pub unsafe fn ivar_ptr<T>(&self, name: &str) -> *mut Twhere T: Encode,

Returns a pointer to the instance variable / ivar with the given name.

This is similar to UnsafeCell::get, see that for more information on what is and isn’t safe to do.

Usually you will have defined the instance variable yourself with ClassBuilder::add_ivar, the type of the ivar T must match the type used in that.

Attempting to access or modify private implementation details of a class that you do no control using this is not supported, and may invoke undefined behaviour.

Library implementors are strongly encouraged to expose a safe interface to the ivar.

Panics

May panic if the object has no ivar with the given name. May also panic if the type encoding of the ivar differs from the type encoding of T.

This should purely seen as help while debugging and is not guaranteed (e.g. it may be disabled when debug_assertions are off).

Safety

The object must have an instance variable with the given name, and it must be of type T. Any invariants that the object have assumed about the value of the instance variable must not be violated.

No thread syncronization is done on accesses to the variable, so you must ensure that any access to the returned pointer do not cause data races, and that Rust’s mutability rules are not otherwise violated.

source

pub unsafe fn ivar<T>(&self, name: &str) -> &Twhere T: Encode,

Returns a reference to the instance variable with the given name.

See AnyObject::ivar_ptr for more information, including on when this panics.

Safety

The object must have an instance variable with the given name, and it must be of type T.

No thread syncronization is done, so you must ensure that no other thread is concurrently mutating the variable. This requirement can be considered upheld if all mutation happens through AnyObject::ivar_mut (since that takes &mut self).

source

pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere T: Encode,

👎Deprecated: Use AnyObject::ivar instead.
source

pub unsafe fn ivar_mut<T>(&mut self, name: &str) -> &mut Twhere T: Encode,

Returns a mutable reference to the ivar with the given name.

See AnyObject::ivar_ptr for more information, including on when this panics.

Safety

The object must have an instance variable with the given name, and it must be of type T.

This access happens through &mut self, which means we know it to be the only reference, hence you do not need to do any work to ensure that data races do not happen.

source

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere T: Encode,

👎Deprecated: Use AnyObject::ivar_mut instead.
source

pub unsafe fn set_ivar<T>(&mut self, name: &str, value: T)where T: Encode,

Sets the value of the ivar with the given name.

This is a shorthand for AnyObject::ivar_mut, see that for more information.

Safety

Same as AnyObject::ivar_mut.