#[repr(C)]pub struct NSURLRequest { /* private fields */ }👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate features
Foundation and Foundation_NSURLRequest only.Implementations
Sourceimpl NSURLRequest
impl NSURLRequest
pub unsafe fn requestWithURL(url: &NSURL) -> Id<Self>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate feature
Foundation_NSURL only.pub unsafe fn supportsSecureCoding() -> bool
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationpub unsafe fn requestWithURL_cachePolicy_timeoutInterval( url: &NSURL, cache_policy: NSURLRequestCachePolicy, timeout_interval: NSTimeInterval, ) -> Id<Self>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate feature
Foundation_NSURL only.pub unsafe fn initWithURL(this: Allocated<Self>, url: &NSURL) -> Id<Self>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate feature
Foundation_NSURL only.pub unsafe fn initWithURL_cachePolicy_timeoutInterval( this: Allocated<Self>, url: &NSURL, cache_policy: NSURLRequestCachePolicy, timeout_interval: NSTimeInterval, ) -> Id<Self>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate feature
Foundation_NSURL only.pub unsafe fn URL(&self) -> Option<Id<NSURL>>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate feature
Foundation_NSURL only.pub unsafe fn cachePolicy(&self) -> NSURLRequestCachePolicy
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationpub unsafe fn timeoutInterval(&self) -> NSTimeInterval
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationpub unsafe fn mainDocumentURL(&self) -> Option<Id<NSURL>>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate feature
Foundation_NSURL only.pub unsafe fn networkServiceType(&self) -> NSURLRequestNetworkServiceType
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationpub unsafe fn allowsCellularAccess(&self) -> bool
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationpub unsafe fn allowsExpensiveNetworkAccess(&self) -> bool
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationpub unsafe fn allowsConstrainedNetworkAccess(&self) -> bool
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationpub unsafe fn assumesHTTP3Capable(&self) -> bool
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationpub unsafe fn attribution(&self) -> NSURLRequestAttribution
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationpub unsafe fn requiresDNSSECValidation(&self) -> bool
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationSourceimpl NSURLRequest
Methods declared on superclass NSObject
impl NSURLRequest
Methods declared on superclass NSObject
Sourceimpl NSURLRequest
NSHTTPURLRequest
impl NSURLRequest
NSHTTPURLRequest
pub unsafe fn HTTPMethod(&self) -> Option<Id<NSString>>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate feature
Foundation_NSString only.pub unsafe fn allHTTPHeaderFields( &self, ) -> Option<Id<NSDictionary<NSString, NSString>>>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate features
Foundation_NSDictionary and Foundation_NSString only.pub unsafe fn valueForHTTPHeaderField( &self, field: &NSString, ) -> Option<Id<NSString>>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate feature
Foundation_NSString only.pub unsafe fn HTTPBody(&self) -> Option<Id<NSData>>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate feature
Foundation_NSData only.pub unsafe fn HTTPBodyStream(&self) -> Option<Id<NSInputStream>>
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationAvailable on crate feature
Foundation_NSInputStream only.pub unsafe fn HTTPShouldHandleCookies(&self) -> bool
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationpub unsafe fn HTTPShouldUsePipelining(&self) -> bool
👎Deprecated:
icrate::Foundation has been moved to objc2-foundationMethods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Available on crate feature AuthenticationServices only.
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
AuthenticationServices only.Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.