Struct NSValue

#[repr(C)]
pub struct NSValue { /* private fields */ }
👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate features Foundation and Foundation_NSValue only.

Implementations

Source

impl NSValue

Creation methods.

pub fn new<T: 'static + Copy + Encode>(value: T) -> Id<Self>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation

Create a new NSValue containing the given type.

Be careful when using this since you may accidentally pass a reference when you wanted to pass a concrete type instead.

Examples

Create an NSValue containing an NSPoint.

use icrate::Foundation::{NSPoint, NSValue};

let val = NSValue::new::<NSPoint>(NSPoint::new(1.0, 1.0));
Source

impl NSValue

Getter methods.

pub unsafe fn get<T: 'static + Copy + Encode>(&self) -> T

👎Deprecated: icrate::Foundation has been moved to objc2-foundation

Retrieve the data contained in the NSValue.

Note that this is broken on GNUStep for some types, see gnustep/libs-base#216.

Safety

The type of T must be what the NSValue actually stores, and any safety invariants that the value has must be upheld.

Note that it may be enough, although is not always, to check whether contains_encoding returns true. For example, NonNull<T> have the same encoding as *const T, but NonNull<T> is clearly not safe to return from this function even if you’ve checked the encoding beforehand.

Examples

Store a pointer in NSValue, and retrieve it again afterwards.

use std::ffi::c_void;
use std::ptr;
use icrate::Foundation::NSValue;

let val = NSValue::new::<*const c_void>(ptr::null());
// SAFETY: The value was just created with a pointer
let res = unsafe { val.get::<*const c_void>() };
assert!(res.is_null());
pub fn get_range(&self) -> Option<NSRange>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub fn get_point(&self) -> Option<NSPoint>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub fn get_size(&self) -> Option<NSSize>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub fn get_rect(&self) -> Option<NSRect>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub fn encoding(&self) -> Option<&str>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub fn contains_encoding<T: 'static + Copy + Encode>(&self) -> bool

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Source

impl NSValue

NSValueGeometryExtensions

pub unsafe fn valueWithPoint(point: NSPoint) -> Id<NSValue>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn valueWithSize(size: NSSize) -> Id<NSValue>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn valueWithRect(rect: NSRect) -> Id<NSValue>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn valueWithEdgeInsets(insets: NSEdgeInsets) -> Id<NSValue>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn pointValue(&self) -> NSPoint

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn sizeValue(&self) -> NSSize

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn rectValue(&self) -> NSRect

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn edgeInsetsValue(&self) -> NSEdgeInsets

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Source

impl NSValue

NSValueRangeExtensions

pub unsafe fn valueWithRange(range: NSRange) -> Id<NSValue>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn rangeValue(&self) -> NSRange

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Source

impl NSValue

pub unsafe fn getValue_size(&self, value: NonNull<c_void>, size: NSUInteger)

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub fn objCType(&self) -> NonNull<c_char>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn initWithBytes_objCType( this: Allocated<Self>, value: NonNull<c_void>, type: NonNull<c_char>, ) -> Id<Self>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn initWithCoder( this: Allocated<Self>, coder: &NSCoder, ) -> Option<Id<Self>>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Available on crate feature Foundation_NSCoder only.
Source

impl NSValue

NSValueCreation

pub unsafe fn valueWithBytes_objCType( value: NonNull<c_void>, type: NonNull<c_char>, ) -> Id<NSValue>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn value_withObjCType( value: NonNull<c_void>, type: NonNull<c_char>, ) -> Id<NSValue>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Source

impl NSValue

NSValueExtensionMethods

pub unsafe fn valueWithNonretainedObject( an_object: Option<&AnyObject>, ) -> Id<NSValue>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn nonretainedObjectValue(&self) -> Option<Id<AnyObject>>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn valueWithPointer(pointer: *mut c_void) -> Id<NSValue>

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub unsafe fn pointerValue(&self) -> *mut c_void

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
pub fn isEqualToValue(&self, value: &NSValue) -> bool

👎Deprecated: icrate::Foundation has been moved to objc2-foundation
Source

impl NSValue

NSDeprecated

pub unsafe fn getValue(&self, value: NonNull<c_void>)

👎Deprecated
Source

impl NSValue

NSValueMapKitGeometryExtensions

pub unsafe fn valueWithMKCoordinate( coordinate: CLLocationCoordinate2D, ) -> Id<NSValue>

👎Deprecated: icrate::MapKit has been moved to objc2-map-kit
Available on crate feature MapKit only.
pub unsafe fn valueWithMKCoordinateSpan(span: MKCoordinateSpan) -> Id<NSValue>

👎Deprecated: icrate::MapKit has been moved to objc2-map-kit
Available on crate feature MapKit only.
pub unsafe fn MKCoordinateValue(&self) -> CLLocationCoordinate2D

👎Deprecated: icrate::MapKit has been moved to objc2-map-kit
Available on crate feature MapKit only.
pub unsafe fn MKCoordinateSpanValue(&self) -> MKCoordinateSpan

👎Deprecated: icrate::MapKit has been moved to objc2-map-kit
Available on crate feature MapKit only.

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Available on crate feature AuthenticationServices only.

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.

Use Ivar::load_mut instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.