#[repr(C)]pub struct DOMHTMLTableCellElement { /* private fields */ }👎Deprecated
Available on crate features
WebKit and WebKit_DOMHTMLTableCellElement only.Implementations
Sourceimpl DOMHTMLTableCellElement
impl DOMHTMLTableCellElement
pub unsafe fn cellIndex(&self) -> c_int
👎Deprecated
pub unsafe fn align(&self) -> Id<NSString>
👎Deprecated
Available on crate feature
Foundation_NSString only.pub unsafe fn setAlign(&self, align: Option<&NSString>)
👎Deprecated
Available on crate feature
Foundation_NSString only.pub unsafe fn axis(&self) -> Id<NSString>
👎Deprecated
Available on crate feature
Foundation_NSString only.pub unsafe fn setAxis(&self, axis: Option<&NSString>)
👎Deprecated
Available on crate feature
Foundation_NSString only.pub unsafe fn bgColor(&self) -> Id<NSString>
👎Deprecated
Available on crate feature
Foundation_NSString only.pub unsafe fn setBgColor(&self, bg_color: Option<&NSString>)
👎Deprecated
Available on crate feature
Foundation_NSString only.pub unsafe fn ch(&self) -> Id<NSString>
👎Deprecated
Available on crate feature
Foundation_NSString only.pub unsafe fn setCh(&self, ch: Option<&NSString>)
👎Deprecated
Available on crate feature
Foundation_NSString only.pub unsafe fn chOff(&self) -> Id<NSString>
👎Deprecated
Available on crate feature
Foundation_NSString only.pub unsafe fn setChOff(&self, ch_off: Option<&NSString>)
👎Deprecated
Available on crate feature
Foundation_NSString only.pub unsafe fn colSpan(&self) -> c_int
👎Deprecated
pub unsafe fn setColSpan(&self, col_span: c_int)
👎Deprecated
pub unsafe fn rowSpan(&self) -> c_int
👎Deprecated
pub unsafe fn setRowSpan(&self, row_span: c_int)
👎Deprecated
pub unsafe fn headers(&self) -> Id<NSString>
👎Deprecated
Available on crate feature
Foundation_NSString only.pub unsafe fn setHeaders(&self, headers: Option<&NSString>)
👎Deprecated
Available on crate feature
Foundation_NSString only.pub unsafe fn height(&self) -> Id<NSString>
👎Deprecated
Available on crate feature
Foundation_NSString only.pub unsafe fn setHeight(&self, height: Option<&NSString>)
👎Deprecated
Available on crate feature
Foundation_NSString only.pub unsafe fn noWrap(&self) -> bool
👎Deprecated
pub unsafe fn setNoWrap(&self, no_wrap: bool)
👎Deprecated
pub unsafe fn vAlign(&self) -> Id<NSString>
👎Deprecated
Available on crate feature
Foundation_NSString only.pub unsafe fn setVAlign(&self, v_align: Option<&NSString>)
👎Deprecated
Available on crate feature
Foundation_NSString only.pub unsafe fn width(&self) -> Id<NSString>
👎Deprecated
Available on crate feature
Foundation_NSString only.pub unsafe fn setWidth(&self, width: Option<&NSString>)
👎Deprecated
Available on crate feature
Foundation_NSString only.pub unsafe fn abbr(&self) -> Id<NSString>
👎Deprecated
Available on crate feature
Foundation_NSString only.pub unsafe fn setAbbr(&self, abbr: Option<&NSString>)
👎Deprecated
Available on crate feature
Foundation_NSString only.pub unsafe fn scope(&self) -> Id<NSString>
👎Deprecated
Available on crate feature
Foundation_NSString only.pub unsafe fn setScope(&self, scope: Option<&NSString>)
👎Deprecated
Available on crate feature
Foundation_NSString only.Sourceimpl DOMHTMLTableCellElement
Methods declared on superclass DOMObject
impl DOMHTMLTableCellElement
Methods declared on superclass DOMObject
Methods from Deref<Target = DOMHTMLElement>
pub unsafe fn title(&self) -> Id<NSString>
👎Deprecated
Available on crate features
WebKit_DOMHTMLElement and Foundation_NSString only.pub unsafe fn setTitle(&self, title: Option<&NSString>)
👎Deprecated
Available on crate features
WebKit_DOMHTMLElement and Foundation_NSString only.pub unsafe fn lang(&self) -> Id<NSString>
👎Deprecated
Available on crate features
WebKit_DOMHTMLElement and Foundation_NSString only.pub unsafe fn setLang(&self, lang: Option<&NSString>)
👎Deprecated
Available on crate features
WebKit_DOMHTMLElement and Foundation_NSString only.pub unsafe fn dir(&self) -> Id<NSString>
👎Deprecated
Available on crate features
WebKit_DOMHTMLElement and Foundation_NSString only.pub unsafe fn setDir(&self, dir: Option<&NSString>)
👎Deprecated
Available on crate features
WebKit_DOMHTMLElement and Foundation_NSString only.pub unsafe fn tabIndex(&self) -> c_int
👎Deprecated
Available on crate feature
WebKit_DOMHTMLElement only.pub unsafe fn setTabIndex(&self, tab_index: c_int)
👎Deprecated
Available on crate feature
WebKit_DOMHTMLElement only.pub unsafe fn accessKey(&self) -> Id<NSString>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMHTMLElement and Foundation_NSString only.pub unsafe fn setAccessKey(&self, access_key: Option<&NSString>)
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMHTMLElement and Foundation_NSString only.pub unsafe fn innerText(&self) -> Id<NSString>
👎Deprecated
Available on crate features
WebKit_DOMHTMLElement and Foundation_NSString only.pub unsafe fn setInnerText(&self, inner_text: Option<&NSString>)
👎Deprecated
Available on crate features
WebKit_DOMHTMLElement and Foundation_NSString only.pub unsafe fn outerText(&self) -> Id<NSString>
👎Deprecated
Available on crate features
WebKit_DOMHTMLElement and Foundation_NSString only.pub unsafe fn setOuterText(&self, outer_text: Option<&NSString>)
👎Deprecated
Available on crate features
WebKit_DOMHTMLElement and Foundation_NSString only.pub unsafe fn contentEditable(&self) -> Id<NSString>
👎Deprecated
Available on crate features
WebKit_DOMHTMLElement and Foundation_NSString only.pub unsafe fn setContentEditable(&self, content_editable: Option<&NSString>)
👎Deprecated
Available on crate features
WebKit_DOMHTMLElement and Foundation_NSString only.pub unsafe fn isContentEditable(&self) -> bool
👎Deprecated
Available on crate feature
WebKit_DOMHTMLElement only.pub unsafe fn idName(&self) -> Id<NSString>
👎Deprecated
Available on crate features
WebKit_DOMHTMLElement and Foundation_NSString only.pub unsafe fn setIdName(&self, id_name: Option<&NSString>)
👎Deprecated
Available on crate features
WebKit_DOMHTMLElement and Foundation_NSString only.pub unsafe fn children(&self) -> Option<Id<DOMHTMLCollection>>
👎Deprecated
Available on crate features
WebKit_DOMHTMLElement and WebKit_DOMHTMLCollection only.pub unsafe fn titleDisplayString(&self) -> Id<NSString>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMHTMLElement and Foundation_NSString only.pub unsafe fn click(&self)
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMHTMLElement only.Methods from Deref<Target = DOMElement>
pub unsafe fn tagName(&self) -> Id<NSString>
👎Deprecated
Available on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn style(&self) -> Option<Id<DOMCSSStyleDeclaration>>
👎Deprecated
Available on crate features
WebKit_DOMElement and WebKit_DOMCSSStyleDeclaration only.pub unsafe fn offsetLeft(&self) -> c_int
👎Deprecated
Available on crate feature
WebKit_DOMElement only.pub unsafe fn offsetTop(&self) -> c_int
👎Deprecated
Available on crate feature
WebKit_DOMElement only.pub unsafe fn offsetWidth(&self) -> c_int
👎Deprecated
Available on crate feature
WebKit_DOMElement only.pub unsafe fn offsetHeight(&self) -> c_int
👎Deprecated
Available on crate feature
WebKit_DOMElement only.pub unsafe fn clientLeft(&self) -> c_int
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMElement only.pub unsafe fn clientTop(&self) -> c_int
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMElement only.pub unsafe fn clientWidth(&self) -> c_int
👎Deprecated
Available on crate feature
WebKit_DOMElement only.pub unsafe fn clientHeight(&self) -> c_int
👎Deprecated
Available on crate feature
WebKit_DOMElement only.pub unsafe fn scrollLeft(&self) -> c_int
👎Deprecated
Available on crate feature
WebKit_DOMElement only.pub unsafe fn setScrollLeft(&self, scroll_left: c_int)
👎Deprecated
Available on crate feature
WebKit_DOMElement only.pub unsafe fn scrollTop(&self) -> c_int
👎Deprecated
Available on crate feature
WebKit_DOMElement only.pub unsafe fn setScrollTop(&self, scroll_top: c_int)
👎Deprecated
Available on crate feature
WebKit_DOMElement only.pub unsafe fn scrollWidth(&self) -> c_int
👎Deprecated
Available on crate feature
WebKit_DOMElement only.pub unsafe fn scrollHeight(&self) -> c_int
👎Deprecated
Available on crate feature
WebKit_DOMElement only.pub unsafe fn offsetParent(&self) -> Option<Id<DOMElement>>
👎Deprecated
Available on crate feature
WebKit_DOMElement only.pub unsafe fn innerHTML(&self) -> Id<NSString>
👎Deprecated
Available on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn setInnerHTML(&self, inner_html: Option<&NSString>)
👎Deprecated
Available on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn outerHTML(&self) -> Id<NSString>
👎Deprecated
Available on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn setOuterHTML(&self, outer_html: Option<&NSString>)
👎Deprecated
Available on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn className(&self) -> Id<NSString>
👎Deprecated
Available on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn setClassName(&self, class_name: Option<&NSString>)
👎Deprecated
Available on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn innerText(&self) -> Id<NSString>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn previousElementSibling(&self) -> Option<Id<DOMElement>>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMElement only.pub unsafe fn nextElementSibling(&self) -> Option<Id<DOMElement>>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMElement only.pub unsafe fn firstElementChild(&self) -> Option<Id<DOMElement>>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMElement only.pub unsafe fn lastElementChild(&self) -> Option<Id<DOMElement>>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMElement only.pub unsafe fn childElementCount(&self) -> c_uint
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMElement only.pub unsafe fn getAttribute( &self, name: Option<&NSString>, ) -> Option<Id<NSString>>
👎Deprecated
Available on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn setAttribute_value( &self, name: Option<&NSString>, value: Option<&NSString>, )
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn removeAttribute(&self, name: Option<&NSString>)
👎Deprecated
Available on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn getAttributeNode( &self, name: Option<&NSString>, ) -> Option<Id<DOMAttr>>
👎Deprecated
Available on crate features
WebKit_DOMElement and Foundation_NSString and WebKit_DOMAttr only.pub unsafe fn setAttributeNode( &self, new_attr: Option<&DOMAttr>, ) -> Option<Id<DOMAttr>>
👎Deprecated
Available on crate features
WebKit_DOMElement and WebKit_DOMAttr only.pub unsafe fn removeAttributeNode( &self, old_attr: Option<&DOMAttr>, ) -> Option<Id<DOMAttr>>
👎Deprecated
Available on crate features
WebKit_DOMElement and WebKit_DOMAttr only.pub unsafe fn getElementsByTagName( &self, name: Option<&NSString>, ) -> Option<Id<DOMNodeList>>
👎Deprecated
Available on crate features
WebKit_DOMElement and Foundation_NSString and WebKit_DOMNodeList only.pub unsafe fn getAttributeNS_localName( &self, namespace_uri: Option<&NSString>, local_name: Option<&NSString>, ) -> Option<Id<NSString>>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn setAttributeNS_qualifiedName_value( &self, namespace_uri: Option<&NSString>, qualified_name: Option<&NSString>, value: Option<&NSString>, )
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn removeAttributeNS_localName( &self, namespace_uri: Option<&NSString>, local_name: Option<&NSString>, )
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn getElementsByTagNameNS_localName( &self, namespace_uri: Option<&NSString>, local_name: Option<&NSString>, ) -> Option<Id<DOMNodeList>>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMElement and Foundation_NSString and WebKit_DOMNodeList only.pub unsafe fn getAttributeNodeNS_localName( &self, namespace_uri: Option<&NSString>, local_name: Option<&NSString>, ) -> Option<Id<DOMAttr>>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMElement and Foundation_NSString and WebKit_DOMAttr only.pub unsafe fn setAttributeNodeNS( &self, new_attr: Option<&DOMAttr>, ) -> Option<Id<DOMAttr>>
👎Deprecated
Available on crate features
WebKit_DOMElement and WebKit_DOMAttr only.pub unsafe fn hasAttribute(&self, name: Option<&NSString>) -> bool
👎Deprecated
Available on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn hasAttributeNS_localName( &self, namespace_uri: Option<&NSString>, local_name: Option<&NSString>, ) -> bool
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn focus(&self)
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMElement only.pub unsafe fn blur(&self)
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMElement only.pub unsafe fn scrollIntoView(&self, align_with_top: bool)
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMElement only.pub unsafe fn scrollIntoViewIfNeeded(&self, center_if_needed: bool)
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMElement only.pub unsafe fn scrollByLines(&self, lines: c_int)
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMElement only.pub unsafe fn scrollByPages(&self, pages: c_int)
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMElement only.pub unsafe fn getElementsByClassName( &self, name: Option<&NSString>, ) -> Option<Id<DOMNodeList>>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMElement and Foundation_NSString and WebKit_DOMNodeList only.pub unsafe fn webkitRequestFullScreen(&self, flags: c_ushort)
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMElement only.pub unsafe fn querySelector( &self, selectors: Option<&NSString>, ) -> Option<Id<DOMElement>>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn querySelectorAll( &self, selectors: Option<&NSString>, ) -> Option<Id<DOMNodeList>>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMElement and Foundation_NSString and WebKit_DOMNodeList only.pub unsafe fn setAttribute( &self, name: Option<&NSString>, value: Option<&NSString>, )
👎Deprecated
Available on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn getAttributeNS( &self, namespace_uri: Option<&NSString>, local_name: Option<&NSString>, ) -> Option<Id<NSString>>
👎Deprecated
Available on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn setAttributeNS( &self, namespace_uri: Option<&NSString>, qualified_name: Option<&NSString>, value: Option<&NSString>, )
👎Deprecated
Available on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn removeAttributeNS( &self, namespace_uri: Option<&NSString>, local_name: Option<&NSString>, )
👎Deprecated
Available on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn getElementsByTagNameNS( &self, namespace_uri: Option<&NSString>, local_name: Option<&NSString>, ) -> Option<Id<DOMNodeList>>
👎Deprecated
Available on crate features
WebKit_DOMElement and Foundation_NSString and WebKit_DOMNodeList only.pub unsafe fn getAttributeNodeNS( &self, namespace_uri: Option<&NSString>, local_name: Option<&NSString>, ) -> Option<Id<DOMAttr>>
👎Deprecated
Available on crate features
WebKit_DOMElement and Foundation_NSString and WebKit_DOMAttr only.pub unsafe fn hasAttributeNS( &self, namespace_uri: Option<&NSString>, local_name: Option<&NSString>, ) -> bool
👎Deprecated
Available on crate features
WebKit_DOMElement and Foundation_NSString only.pub unsafe fn image(&self) -> Option<Id<NSImage>>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMElement and AppKit_NSImage only.Methods from Deref<Target = DOMNode>
pub unsafe fn boundingBox(&self) -> NSRect
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMNode only.pub unsafe fn lineBoxRects(&self) -> Option<Id<NSArray>>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMNode and Foundation_NSArray only.pub unsafe fn nodeName(&self) -> Id<NSString>
👎Deprecated
Available on crate features
WebKit_DOMNode and Foundation_NSString only.pub unsafe fn nodeValue(&self) -> Id<NSString>
👎Deprecated
Available on crate features
WebKit_DOMNode and Foundation_NSString only.pub unsafe fn setNodeValue(&self, node_value: Option<&NSString>)
👎Deprecated
Available on crate features
WebKit_DOMNode and Foundation_NSString only.pub unsafe fn nodeType(&self) -> c_ushort
👎Deprecated
Available on crate feature
WebKit_DOMNode only.pub unsafe fn parentNode(&self) -> Option<Id<DOMNode>>
👎Deprecated
Available on crate feature
WebKit_DOMNode only.pub unsafe fn childNodes(&self) -> Option<Id<DOMNodeList>>
👎Deprecated
Available on crate features
WebKit_DOMNode and WebKit_DOMNodeList only.pub unsafe fn firstChild(&self) -> Option<Id<DOMNode>>
👎Deprecated
Available on crate feature
WebKit_DOMNode only.pub unsafe fn lastChild(&self) -> Option<Id<DOMNode>>
👎Deprecated
Available on crate feature
WebKit_DOMNode only.pub unsafe fn previousSibling(&self) -> Option<Id<DOMNode>>
👎Deprecated
Available on crate feature
WebKit_DOMNode only.pub unsafe fn nextSibling(&self) -> Option<Id<DOMNode>>
👎Deprecated
Available on crate feature
WebKit_DOMNode only.pub unsafe fn ownerDocument(&self) -> Option<Id<DOMDocument>>
👎Deprecated
Available on crate features
WebKit_DOMNode and WebKit_DOMDocument only.pub unsafe fn namespaceURI(&self) -> Id<NSString>
👎Deprecated
Available on crate features
WebKit_DOMNode and Foundation_NSString only.pub unsafe fn prefix(&self) -> Id<NSString>
👎Deprecated
Available on crate features
WebKit_DOMNode and Foundation_NSString only.pub unsafe fn setPrefix(&self, prefix: Option<&NSString>)
👎Deprecated
Available on crate features
WebKit_DOMNode and Foundation_NSString only.pub unsafe fn localName(&self) -> Id<NSString>
👎Deprecated
Available on crate features
WebKit_DOMNode and Foundation_NSString only.pub unsafe fn attributes(&self) -> Option<Id<DOMNamedNodeMap>>
👎Deprecated
Available on crate features
WebKit_DOMNode and WebKit_DOMNamedNodeMap only.pub unsafe fn baseURI(&self) -> Id<NSString>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMNode and Foundation_NSString only.pub unsafe fn textContent(&self) -> Id<NSString>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMNode and Foundation_NSString only.pub unsafe fn setTextContent(&self, text_content: Option<&NSString>)
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMNode and Foundation_NSString only.pub unsafe fn parentElement(&self) -> Option<Id<DOMElement>>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMNode and WebKit_DOMElement only.pub unsafe fn isContentEditable(&self) -> bool
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMNode only.pub unsafe fn insertBefore_refChild( &self, new_child: Option<&DOMNode>, ref_child: Option<&DOMNode>, ) -> Option<Id<DOMNode>>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMNode only.pub unsafe fn replaceChild_oldChild( &self, new_child: Option<&DOMNode>, old_child: Option<&DOMNode>, ) -> Option<Id<DOMNode>>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMNode only.pub unsafe fn removeChild( &self, old_child: Option<&DOMNode>, ) -> Option<Id<DOMNode>>
👎Deprecated
Available on crate feature
WebKit_DOMNode only.pub unsafe fn appendChild( &self, new_child: Option<&DOMNode>, ) -> Option<Id<DOMNode>>
👎Deprecated
Available on crate feature
WebKit_DOMNode only.pub unsafe fn hasChildNodes(&self) -> bool
👎Deprecated
Available on crate feature
WebKit_DOMNode only.pub unsafe fn cloneNode(&self, deep: bool) -> Option<Id<DOMNode>>
👎Deprecated
Available on crate feature
WebKit_DOMNode only.pub unsafe fn normalize(&self)
👎Deprecated
Available on crate feature
WebKit_DOMNode only.pub unsafe fn isSupported_version( &self, feature: Option<&NSString>, version: Option<&NSString>, ) -> bool
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMNode and Foundation_NSString only.pub unsafe fn hasAttributes(&self) -> bool
👎Deprecated
Available on crate feature
WebKit_DOMNode only.pub unsafe fn isSameNode(&self, other: Option<&DOMNode>) -> bool
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMNode only.pub unsafe fn isEqualNode(&self, other: Option<&DOMNode>) -> bool
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMNode only.pub unsafe fn lookupPrefix( &self, namespace_uri: Option<&NSString>, ) -> Option<Id<NSString>>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMNode and Foundation_NSString only.pub unsafe fn lookupNamespaceURI( &self, prefix: Option<&NSString>, ) -> Option<Id<NSString>>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMNode and Foundation_NSString only.pub unsafe fn isDefaultNamespace( &self, namespace_uri: Option<&NSString>, ) -> bool
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMNode and Foundation_NSString only.pub unsafe fn compareDocumentPosition( &self, other: Option<&DOMNode>, ) -> c_ushort
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMNode only.pub unsafe fn contains(&self, other: Option<&DOMNode>) -> bool
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate feature
WebKit_DOMNode only.pub unsafe fn insertBefore( &self, new_child: Option<&DOMNode>, ref_child: Option<&DOMNode>, ) -> Option<Id<DOMNode>>
👎Deprecated
Available on crate feature
WebKit_DOMNode only.pub unsafe fn replaceChild( &self, new_child: Option<&DOMNode>, old_child: Option<&DOMNode>, ) -> Option<Id<DOMNode>>
👎Deprecated
Available on crate feature
WebKit_DOMNode only.pub unsafe fn isSupported( &self, feature: Option<&NSString>, version: Option<&NSString>, ) -> bool
👎Deprecated
Available on crate features
WebKit_DOMNode and Foundation_NSString only.pub unsafe fn webArchive(&self) -> Option<Id<WebArchive>>
👎Deprecated
Available on crate features
WebKit_DOMNode and WebKit_WebArchive only.Methods from Deref<Target = DOMObject>
pub unsafe fn sheet(&self) -> Option<Id<DOMStyleSheet>>
👎Deprecated:
icrate::WebKit has been moved to objc2-web-kitAvailable on crate features
WebKit_DOMObject and WebKit_DOMStyleSheet only.Methods from Deref<Target = WebScriptObject>
pub unsafe fn callWebScriptMethod_withArguments( &self, name: Option<&NSString>, arguments: Option<&NSArray>, ) -> Option<Id<AnyObject>>
👎Deprecated
Available on crate features
WebKit_WebScriptObject and Foundation_NSArray and Foundation_NSString only.pub unsafe fn evaluateWebScript( &self, script: Option<&NSString>, ) -> Option<Id<AnyObject>>
👎Deprecated
Available on crate features
WebKit_WebScriptObject and Foundation_NSString only.pub unsafe fn removeWebScriptKey(&self, name: Option<&NSString>)
👎Deprecated
Available on crate features
WebKit_WebScriptObject and Foundation_NSString only.pub unsafe fn stringRepresentation(&self) -> Option<Id<NSString>>
👎Deprecated
Available on crate features
WebKit_WebScriptObject and Foundation_NSString only.pub unsafe fn webScriptValueAtIndex( &self, index: c_uint, ) -> Option<Id<AnyObject>>
👎Deprecated
Available on crate feature
WebKit_WebScriptObject only.pub unsafe fn setWebScriptValueAtIndex_value( &self, index: c_uint, value: Option<&AnyObject>, )
👎Deprecated
Available on crate feature
WebKit_WebScriptObject only.pub unsafe fn setException(&self, description: Option<&NSString>)
👎Deprecated
Available on crate features
WebKit_WebScriptObject and Foundation_NSString only.Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Available on crate feature AuthenticationServices only.
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
AuthenticationServices only.Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.