#[repr(C)]
pub struct DOMProcessingInstruction { /* private fields */ }
👎Deprecated
Available on crate features WebKit and WebKit_DOMProcessingInstruction only.

Implementations

source

impl DOMProcessingInstruction

source

pub unsafe fn target(&self) -> Id<NSString>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn sheet(&self) -> Option<Id<DOMStyleSheet>>

Available on crate feature WebKit_DOMStyleSheet only.
source

impl DOMProcessingInstruction

Methods declared on superclass DOMObject

source

pub unsafe fn init(this: Option<Allocated<Self>>) -> Id<Self>

source

impl DOMProcessingInstruction

Methods declared on superclass NSObject

source

pub unsafe fn new() -> Id<Self>

Methods from Deref<Target = DOMCharacterData>

source

pub unsafe fn data(&self) -> Id<NSString>

Available on crate features WebKit_DOMCharacterData and Foundation_NSString only.
source

pub unsafe fn setData(&self, data: Option<&NSString>)

Available on crate features WebKit_DOMCharacterData and Foundation_NSString only.
source

pub unsafe fn length(&self) -> c_uint

Available on crate feature WebKit_DOMCharacterData only.
source

pub unsafe fn substringData_length( &self, offset: c_uint, length: c_uint ) -> Option<Id<NSString>>

Available on crate features WebKit_DOMCharacterData and Foundation_NSString only.
source

pub unsafe fn appendData(&self, data: Option<&NSString>)

Available on crate features WebKit_DOMCharacterData and Foundation_NSString only.
source

pub unsafe fn insertData_data(&self, offset: c_uint, data: Option<&NSString>)

Available on crate features WebKit_DOMCharacterData and Foundation_NSString only.
source

pub unsafe fn deleteData_length(&self, offset: c_uint, length: c_uint)

Available on crate feature WebKit_DOMCharacterData only.
source

pub unsafe fn replaceData_length_data( &self, offset: c_uint, length: c_uint, data: Option<&NSString> )

Available on crate features WebKit_DOMCharacterData and Foundation_NSString only.
source

pub unsafe fn substringData( &self, offset: c_uint, length: c_uint ) -> Option<Id<NSString>>

👎Deprecated
Available on crate features WebKit_DOMCharacterData and Foundation_NSString only.
source

pub unsafe fn insertData(&self, offset: c_uint, data: Option<&NSString>)

👎Deprecated
Available on crate features WebKit_DOMCharacterData and Foundation_NSString only.
source

pub unsafe fn deleteData(&self, offset: c_uint, length: c_uint)

👎Deprecated
Available on crate feature WebKit_DOMCharacterData only.
source

pub unsafe fn replaceData( &self, offset: c_uint, length: c_uint, data: Option<&NSString> )

👎Deprecated
Available on crate features WebKit_DOMCharacterData and Foundation_NSString only.

Methods from Deref<Target = DOMNode>

source

pub unsafe fn boundingBox(&self) -> NSRect

Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn lineBoxRects(&self) -> Option<Id<NSArray>>

Available on crate features WebKit_DOMNode and Foundation_NSArray only.
source

pub unsafe fn nodeName(&self) -> Id<NSString>

Available on crate features WebKit_DOMNode and Foundation_NSString only.
source

pub unsafe fn nodeValue(&self) -> Id<NSString>

Available on crate features WebKit_DOMNode and Foundation_NSString only.
source

pub unsafe fn setNodeValue(&self, node_value: Option<&NSString>)

Available on crate features WebKit_DOMNode and Foundation_NSString only.
source

pub unsafe fn nodeType(&self) -> c_ushort

Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn parentNode(&self) -> Option<Id<DOMNode>>

Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn childNodes(&self) -> Option<Id<DOMNodeList>>

Available on crate features WebKit_DOMNode and WebKit_DOMNodeList only.
source

pub unsafe fn firstChild(&self) -> Option<Id<DOMNode>>

Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn lastChild(&self) -> Option<Id<DOMNode>>

Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn previousSibling(&self) -> Option<Id<DOMNode>>

Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn nextSibling(&self) -> Option<Id<DOMNode>>

Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn ownerDocument(&self) -> Option<Id<DOMDocument>>

Available on crate features WebKit_DOMNode and WebKit_DOMDocument only.
source

pub unsafe fn namespaceURI(&self) -> Id<NSString>

Available on crate features WebKit_DOMNode and Foundation_NSString only.
source

pub unsafe fn prefix(&self) -> Id<NSString>

Available on crate features WebKit_DOMNode and Foundation_NSString only.
source

pub unsafe fn setPrefix(&self, prefix: Option<&NSString>)

Available on crate features WebKit_DOMNode and Foundation_NSString only.
source

pub unsafe fn localName(&self) -> Id<NSString>

Available on crate features WebKit_DOMNode and Foundation_NSString only.
source

pub unsafe fn attributes(&self) -> Option<Id<DOMNamedNodeMap>>

Available on crate features WebKit_DOMNode and WebKit_DOMNamedNodeMap only.
source

pub unsafe fn baseURI(&self) -> Id<NSString>

Available on crate features WebKit_DOMNode and Foundation_NSString only.
source

pub unsafe fn textContent(&self) -> Id<NSString>

Available on crate features WebKit_DOMNode and Foundation_NSString only.
source

pub unsafe fn setTextContent(&self, text_content: Option<&NSString>)

Available on crate features WebKit_DOMNode and Foundation_NSString only.
source

pub unsafe fn parentElement(&self) -> Option<Id<DOMElement>>

Available on crate features WebKit_DOMNode and WebKit_DOMElement only.
source

pub unsafe fn isContentEditable(&self) -> bool

Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn insertBefore_refChild( &self, new_child: Option<&DOMNode>, ref_child: Option<&DOMNode> ) -> Option<Id<DOMNode>>

Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn replaceChild_oldChild( &self, new_child: Option<&DOMNode>, old_child: Option<&DOMNode> ) -> Option<Id<DOMNode>>

Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn removeChild( &self, old_child: Option<&DOMNode> ) -> Option<Id<DOMNode>>

Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn appendChild( &self, new_child: Option<&DOMNode> ) -> Option<Id<DOMNode>>

Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn hasChildNodes(&self) -> bool

Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn cloneNode(&self, deep: bool) -> Option<Id<DOMNode>>

Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn normalize(&self)

Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn isSupported_version( &self, feature: Option<&NSString>, version: Option<&NSString> ) -> bool

Available on crate features WebKit_DOMNode and Foundation_NSString only.
source

pub unsafe fn hasAttributes(&self) -> bool

Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn isSameNode(&self, other: Option<&DOMNode>) -> bool

Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn isEqualNode(&self, other: Option<&DOMNode>) -> bool

Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn lookupPrefix( &self, namespace_uri: Option<&NSString> ) -> Option<Id<NSString>>

Available on crate features WebKit_DOMNode and Foundation_NSString only.
source

pub unsafe fn lookupNamespaceURI( &self, prefix: Option<&NSString> ) -> Option<Id<NSString>>

Available on crate features WebKit_DOMNode and Foundation_NSString only.
source

pub unsafe fn isDefaultNamespace( &self, namespace_uri: Option<&NSString> ) -> bool

Available on crate features WebKit_DOMNode and Foundation_NSString only.
source

pub unsafe fn compareDocumentPosition( &self, other: Option<&DOMNode> ) -> c_ushort

Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn contains(&self, other: Option<&DOMNode>) -> bool

Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn insertBefore( &self, new_child: Option<&DOMNode>, ref_child: Option<&DOMNode> ) -> Option<Id<DOMNode>>

👎Deprecated
Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn replaceChild( &self, new_child: Option<&DOMNode>, old_child: Option<&DOMNode> ) -> Option<Id<DOMNode>>

👎Deprecated
Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn isSupported( &self, feature: Option<&NSString>, version: Option<&NSString> ) -> bool

👎Deprecated
Available on crate features WebKit_DOMNode and Foundation_NSString only.
source

pub unsafe fn webArchive(&self) -> Option<Id<WebArchive>>

Available on crate features WebKit_DOMNode and WebKit_WebArchive only.

Methods from Deref<Target = DOMObject>

source

pub unsafe fn sheet(&self) -> Option<Id<DOMStyleSheet>>

Available on crate features WebKit_DOMObject and WebKit_DOMStyleSheet only.

Methods from Deref<Target = WebScriptObject>

source

pub unsafe fn callWebScriptMethod_withArguments( &self, name: Option<&NSString>, arguments: Option<&NSArray> ) -> Option<Id<AnyObject>>

Available on crate features WebKit_WebScriptObject and Foundation_NSArray and Foundation_NSString only.
source

pub unsafe fn evaluateWebScript( &self, script: Option<&NSString> ) -> Option<Id<AnyObject>>

Available on crate features WebKit_WebScriptObject and Foundation_NSString only.
source

pub unsafe fn removeWebScriptKey(&self, name: Option<&NSString>)

Available on crate features WebKit_WebScriptObject and Foundation_NSString only.
source

pub unsafe fn stringRepresentation(&self) -> Option<Id<NSString>>

Available on crate features WebKit_WebScriptObject and Foundation_NSString only.
source

pub unsafe fn webScriptValueAtIndex( &self, index: c_uint ) -> Option<Id<AnyObject>>

Available on crate feature WebKit_WebScriptObject only.
source

pub unsafe fn setWebScriptValueAtIndex_value( &self, index: c_uint, value: Option<&AnyObject> )

Available on crate feature WebKit_WebScriptObject only.
source

pub unsafe fn setException(&self, description: Option<&NSString>)

Available on crate features WebKit_WebScriptObject and Foundation_NSString only.

Methods from Deref<Target = AnyObject>

source

pub fn class(&self) -> &AnyClass

Dynamically find the class of this object.

source

pub unsafe fn ivar_ptr<T>(&self, name: &str) -> *mut Twhere T: Encode,

Returns a pointer to the instance variable / ivar with the given name.

This is similar to UnsafeCell::get, see that for more information on what is and isn’t safe to do.

Usually you will have defined the instance variable yourself with ClassBuilder::add_ivar, the type of the ivar T must match the type used in that.

Attempting to access or modify private implementation details of a class that you do no control using this is not supported, and may invoke undefined behaviour.

Library implementors are strongly encouraged to expose a safe interface to the ivar.

Panics

May panic if the object has no ivar with the given name. May also panic if the type encoding of the ivar differs from the type encoding of T.

This should purely seen as help while debugging and is not guaranteed (e.g. it may be disabled when debug_assertions are off).

Safety

The object must have an instance variable with the given name, and it must be of type T. Any invariants that the object have assumed about the value of the instance variable must not be violated.

No thread syncronization is done on accesses to the variable, so you must ensure that any access to the returned pointer do not cause data races, and that Rust’s mutability rules are not otherwise violated.

source

pub unsafe fn ivar<T>(&self, name: &str) -> &Twhere T: Encode,

Returns a reference to the instance variable with the given name.

See AnyObject::ivar_ptr for more information, including on when this panics.

Safety

The object must have an instance variable with the given name, and it must be of type T.

No thread syncronization is done, so you must ensure that no other thread is concurrently mutating the variable. This requirement can be considered upheld if all mutation happens through AnyObject::ivar_mut (since that takes &mut self).

source

pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere T: Encode,

👎Deprecated: Use AnyObject::ivar instead.
source

pub unsafe fn ivar_mut<T>(&mut self, name: &str) -> &mut Twhere T: Encode,

Returns a mutable reference to the ivar with the given name.

See AnyObject::ivar_ptr for more information, including on when this panics.

Safety

The object must have an instance variable with the given name, and it must be of type T.

This access happens through &mut self, which means we know it to be the only reference, hence you do not need to do any work to ensure that data races do not happen.

source

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere T: Encode,

👎Deprecated: Use AnyObject::ivar_mut instead.
source

pub unsafe fn set_ivar<T>(&mut self, name: &str, value: T)where T: Encode,

Sets the value of the ivar with the given name.

This is a shorthand for AnyObject::ivar_mut, see that for more information.

Safety

Same as AnyObject::ivar_mut.