#[repr(C)]
pub struct DOMStyleSheet { /* private fields */ }
👎Deprecated
Available on crate features WebKit and WebKit_DOMStyleSheet only.

Implementations

source

impl DOMStyleSheet

source

pub unsafe fn type(&self) -> Id<NSString>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn disabled(&self) -> bool

source

pub unsafe fn setDisabled(&self, disabled: bool)

source

pub unsafe fn ownerNode(&self) -> Option<Id<DOMNode>>

Available on crate feature WebKit_DOMNode only.
source

pub unsafe fn parentStyleSheet(&self) -> Option<Id<DOMStyleSheet>>

source

pub unsafe fn href(&self) -> Id<NSString>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn title(&self) -> Id<NSString>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn media(&self) -> Option<Id<DOMMediaList>>

Available on crate feature WebKit_DOMMediaList only.
source

impl DOMStyleSheet

Methods declared on superclass DOMObject

source

pub unsafe fn init(this: Option<Allocated<Self>>) -> Id<Self>

source

impl DOMStyleSheet

Methods declared on superclass NSObject

source

pub unsafe fn new() -> Id<Self>

Methods from Deref<Target = DOMObject>

source

pub unsafe fn sheet(&self) -> Option<Id<DOMStyleSheet>>

Available on crate feature WebKit_DOMObject only.

Methods from Deref<Target = WebScriptObject>

source

pub unsafe fn callWebScriptMethod_withArguments( &self, name: Option<&NSString>, arguments: Option<&NSArray> ) -> Option<Id<AnyObject>>

Available on crate features WebKit_WebScriptObject and Foundation_NSArray and Foundation_NSString only.
source

pub unsafe fn evaluateWebScript( &self, script: Option<&NSString> ) -> Option<Id<AnyObject>>

Available on crate features WebKit_WebScriptObject and Foundation_NSString only.
source

pub unsafe fn removeWebScriptKey(&self, name: Option<&NSString>)

Available on crate features WebKit_WebScriptObject and Foundation_NSString only.
source

pub unsafe fn stringRepresentation(&self) -> Option<Id<NSString>>

Available on crate features WebKit_WebScriptObject and Foundation_NSString only.
source

pub unsafe fn webScriptValueAtIndex( &self, index: c_uint ) -> Option<Id<AnyObject>>

Available on crate feature WebKit_WebScriptObject only.
source

pub unsafe fn setWebScriptValueAtIndex_value( &self, index: c_uint, value: Option<&AnyObject> )

Available on crate feature WebKit_WebScriptObject only.
source

pub unsafe fn setException(&self, description: Option<&NSString>)

Available on crate features WebKit_WebScriptObject and Foundation_NSString only.

Methods from Deref<Target = AnyObject>

source

pub fn class(&self) -> &AnyClass

Dynamically find the class of this object.

source

pub unsafe fn ivar_ptr<T>(&self, name: &str) -> *mut Twhere T: Encode,

Returns a pointer to the instance variable / ivar with the given name.

This is similar to UnsafeCell::get, see that for more information on what is and isn’t safe to do.

Usually you will have defined the instance variable yourself with ClassBuilder::add_ivar, the type of the ivar T must match the type used in that.

Attempting to access or modify private implementation details of a class that you do no control using this is not supported, and may invoke undefined behaviour.

Library implementors are strongly encouraged to expose a safe interface to the ivar.

Panics

May panic if the object has no ivar with the given name. May also panic if the type encoding of the ivar differs from the type encoding of T.

This should purely seen as help while debugging and is not guaranteed (e.g. it may be disabled when debug_assertions are off).

Safety

The object must have an instance variable with the given name, and it must be of type T. Any invariants that the object have assumed about the value of the instance variable must not be violated.

No thread syncronization is done on accesses to the variable, so you must ensure that any access to the returned pointer do not cause data races, and that Rust’s mutability rules are not otherwise violated.

source

pub unsafe fn ivar<T>(&self, name: &str) -> &Twhere T: Encode,

Returns a reference to the instance variable with the given name.

See AnyObject::ivar_ptr for more information, including on when this panics.

Safety

The object must have an instance variable with the given name, and it must be of type T.

No thread syncronization is done, so you must ensure that no other thread is concurrently mutating the variable. This requirement can be considered upheld if all mutation happens through AnyObject::ivar_mut (since that takes &mut self).

source

pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere T: Encode,

👎Deprecated: Use AnyObject::ivar instead.
source

pub unsafe fn ivar_mut<T>(&mut self, name: &str) -> &mut Twhere T: Encode,

Returns a mutable reference to the ivar with the given name.

See AnyObject::ivar_ptr for more information, including on when this panics.

Safety

The object must have an instance variable with the given name, and it must be of type T.

This access happens through &mut self, which means we know it to be the only reference, hence you do not need to do any work to ensure that data races do not happen.

source

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere T: Encode,

👎Deprecated: Use AnyObject::ivar_mut instead.
source

pub unsafe fn set_ivar<T>(&mut self, name: &str, value: T)where T: Encode,

Sets the value of the ivar with the given name.

This is a shorthand for AnyObject::ivar_mut, see that for more information.

Safety

Same as AnyObject::ivar_mut.