Struct icrate::Foundation::NSCoder

source ·
#[repr(C)]
pub struct NSCoder { /* private fields */ }
Available on crate features Foundation and Foundation_NSCoder only.

Implementations

source

impl NSCoder

NSAppKitColorExtensions

source

pub unsafe fn decodeNXColor(&self) -> Option<Id<NSColor>>

👎Deprecated
Available on crate features AppKit and AppKit_NSColor only.
source

impl NSCoder

source

pub unsafe fn encodeValueOfObjCType_at( &self, type: NonNull<c_char>, addr: NonNull<c_void> )

source

pub unsafe fn encodeDataObject(&self, data: &NSData)

Available on crate feature Foundation_NSData only.
source

pub unsafe fn decodeDataObject(&self) -> Option<Id<NSData>>

Available on crate feature Foundation_NSData only.
source

pub unsafe fn decodeValueOfObjCType_at_size( &self, type: NonNull<c_char>, data: NonNull<c_void>, size: NSUInteger )

source

pub unsafe fn versionForClassName(&self, class_name: &NSString) -> NSInteger

Available on crate feature Foundation_NSString only.
source

impl NSCoder

Methods declared on superclass NSObject

source

pub unsafe fn init(this: Option<Allocated<Self>>) -> Id<Self>

source

pub unsafe fn new() -> Id<Self>

source

impl NSCoder

NSExtendedCoder

source

pub unsafe fn encodeObject(&self, object: Option<&AnyObject>)

source

pub unsafe fn encodeRootObject(&self, root_object: &AnyObject)

source

pub unsafe fn encodeBycopyObject(&self, an_object: Option<&AnyObject>)

source

pub unsafe fn encodeByrefObject(&self, an_object: Option<&AnyObject>)

source

pub unsafe fn encodeConditionalObject(&self, object: Option<&AnyObject>)

source

pub unsafe fn encodeArrayOfObjCType_count_at( &self, type: NonNull<c_char>, count: NSUInteger, array: NonNull<c_void> )

source

pub unsafe fn encodeBytes_length( &self, byteaddr: *mut c_void, length: NSUInteger )

source

pub unsafe fn decodeObject(&self) -> Option<Id<AnyObject>>

source

pub unsafe fn decodeTopLevelObjectAndReturnError( &self ) -> Result<Id<AnyObject>, Id<NSError>>

Available on crate feature Foundation_NSError only.
source

pub unsafe fn decodeArrayOfObjCType_count_at( &self, item_type: NonNull<c_char>, count: NSUInteger, array: NonNull<c_void> )

source

pub unsafe fn decodeBytesWithReturnedLength( &self, lengthp: NonNull<NSUInteger> ) -> *mut c_void

source

pub unsafe fn encodePropertyList(&self, a_property_list: &AnyObject)

source

pub unsafe fn decodePropertyList(&self) -> Option<Id<AnyObject>>

source

pub unsafe fn setObjectZone(&self, zone: *mut NSZone)

source

pub unsafe fn objectZone(&self) -> *mut NSZone

source

pub unsafe fn systemVersion(&self) -> c_uint

source

pub unsafe fn allowsKeyedCoding(&self) -> bool

source

pub unsafe fn encodeObject_forKey( &self, object: Option<&AnyObject>, key: &NSString )

Available on crate feature Foundation_NSString only.
source

pub unsafe fn encodeConditionalObject_forKey( &self, object: Option<&AnyObject>, key: &NSString )

Available on crate feature Foundation_NSString only.
source

pub unsafe fn encodeBool_forKey(&self, value: bool, key: &NSString)

Available on crate feature Foundation_NSString only.
source

pub unsafe fn encodeInt_forKey(&self, value: c_int, key: &NSString)

Available on crate feature Foundation_NSString only.
source

pub unsafe fn encodeInt32_forKey(&self, value: i32, key: &NSString)

Available on crate feature Foundation_NSString only.
source

pub unsafe fn encodeInt64_forKey(&self, value: i64, key: &NSString)

Available on crate feature Foundation_NSString only.
source

pub unsafe fn encodeFloat_forKey(&self, value: c_float, key: &NSString)

Available on crate feature Foundation_NSString only.
source

pub unsafe fn encodeDouble_forKey(&self, value: c_double, key: &NSString)

Available on crate feature Foundation_NSString only.
source

pub unsafe fn encodeBytes_length_forKey( &self, bytes: *mut u8, length: NSUInteger, key: &NSString )

Available on crate feature Foundation_NSString only.
source

pub unsafe fn containsValueForKey(&self, key: &NSString) -> bool

Available on crate feature Foundation_NSString only.
source

pub unsafe fn decodeObjectForKey(&self, key: &NSString) -> Option<Id<AnyObject>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn decodeTopLevelObjectForKey_error( &self, key: &NSString ) -> Result<Id<AnyObject>, Id<NSError>>

Available on crate features Foundation_NSError and Foundation_NSString only.
source

pub unsafe fn decodeBoolForKey(&self, key: &NSString) -> bool

Available on crate feature Foundation_NSString only.
source

pub unsafe fn decodeIntForKey(&self, key: &NSString) -> c_int

Available on crate feature Foundation_NSString only.
source

pub unsafe fn decodeInt32ForKey(&self, key: &NSString) -> i32

Available on crate feature Foundation_NSString only.
source

pub unsafe fn decodeInt64ForKey(&self, key: &NSString) -> i64

Available on crate feature Foundation_NSString only.
source

pub unsafe fn decodeFloatForKey(&self, key: &NSString) -> c_float

Available on crate feature Foundation_NSString only.
source

pub unsafe fn decodeDoubleForKey(&self, key: &NSString) -> c_double

Available on crate feature Foundation_NSString only.
source

pub unsafe fn decodeBytesForKey_returnedLength( &self, key: &NSString, lengthp: *mut NSUInteger ) -> *mut u8

Available on crate feature Foundation_NSString only.
source

pub unsafe fn encodeInteger_forKey(&self, value: NSInteger, key: &NSString)

Available on crate feature Foundation_NSString only.
source

pub unsafe fn decodeIntegerForKey(&self, key: &NSString) -> NSInteger

Available on crate feature Foundation_NSString only.
source

pub unsafe fn requiresSecureCoding(&self) -> bool

source

pub unsafe fn decodeObjectOfClass_forKey( &self, a_class: &AnyClass, key: &NSString ) -> Option<Id<AnyObject>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn decodeTopLevelObjectOfClass_forKey_error( &self, a_class: &AnyClass, key: &NSString ) -> Result<Id<AnyObject>, Id<NSError>>

Available on crate features Foundation_NSError and Foundation_NSString only.
source

pub unsafe fn decodeArrayOfObjectsOfClass_forKey( &self, cls: &AnyClass, key: &NSString ) -> Option<Id<NSArray>>

Available on crate features Foundation_NSArray and Foundation_NSString only.
source

pub unsafe fn decodeDictionaryWithKeysOfClass_objectsOfClass_forKey( &self, key_cls: &AnyClass, object_cls: &AnyClass, key: &NSString ) -> Option<Id<NSDictionary>>

Available on crate features Foundation_NSDictionary and Foundation_NSString only.
source

pub unsafe fn decodeObjectOfClasses_forKey( &self, classes: Option<&NSSet<AnyObject>>, key: &NSString ) -> Option<Id<AnyObject>>

Available on crate features Foundation_NSSet and Foundation_NSString only.
source

pub unsafe fn decodeTopLevelObjectOfClasses_forKey_error( &self, classes: Option<&NSSet<AnyObject>>, key: &NSString ) -> Result<Id<AnyObject>, Id<NSError>>

Available on crate features Foundation_NSError and Foundation_NSSet and Foundation_NSString only.
source

pub unsafe fn decodeArrayOfObjectsOfClasses_forKey( &self, classes: &NSSet<AnyObject>, key: &NSString ) -> Option<Id<NSArray>>

Available on crate features Foundation_NSArray and Foundation_NSSet and Foundation_NSString only.
source

pub unsafe fn decodeDictionaryWithKeysOfClasses_objectsOfClasses_forKey( &self, key_classes: &NSSet<AnyObject>, object_classes: &NSSet<AnyObject>, key: &NSString ) -> Option<Id<NSDictionary>>

Available on crate features Foundation_NSDictionary and Foundation_NSSet and Foundation_NSString only.
source

pub unsafe fn decodePropertyListForKey( &self, key: &NSString ) -> Option<Id<AnyObject>>

Available on crate feature Foundation_NSString only.
source

pub unsafe fn allowedClasses(&self) -> Option<Id<NSSet<AnyObject>>>

Available on crate feature Foundation_NSSet only.
source

pub unsafe fn failWithError(&self, error: &NSError)

Available on crate feature Foundation_NSError only.
source

pub unsafe fn decodingFailurePolicy(&self) -> NSDecodingFailurePolicy

source

pub unsafe fn error(&self) -> Option<Id<NSError>>

Available on crate feature Foundation_NSError only.
source

impl NSCoder

NSTypedstreamCompatibility

source

pub unsafe fn encodeNXObject(&self, object: &AnyObject)

👎Deprecated: Not supported
source

pub unsafe fn decodeNXObject(&self) -> Option<Id<AnyObject>>

👎Deprecated: Not supported
source

impl NSCoder

NSDeprecated

source

pub unsafe fn decodeValueOfObjCType_at( &self, type: NonNull<c_char>, data: NonNull<c_void> )

👎Deprecated
source

impl NSCoder

NSGeometryCoding

source

pub unsafe fn encodePoint(&self, point: NSPoint)

source

pub unsafe fn decodePoint(&self) -> NSPoint

source

pub unsafe fn encodeSize(&self, size: NSSize)

source

pub unsafe fn decodeSize(&self) -> NSSize

source

pub unsafe fn encodeRect(&self, rect: NSRect)

source

pub unsafe fn decodeRect(&self) -> NSRect

source

impl NSCoder

NSGeometryKeyedCoding

source

pub unsafe fn encodePoint_forKey(&self, point: NSPoint, key: &NSString)

Available on crate feature Foundation_NSString only.
source

pub unsafe fn encodeSize_forKey(&self, size: NSSize, key: &NSString)

Available on crate feature Foundation_NSString only.
source

pub unsafe fn encodeRect_forKey(&self, rect: NSRect, key: &NSString)

Available on crate feature Foundation_NSString only.
source

pub unsafe fn decodePointForKey(&self, key: &NSString) -> NSPoint

Available on crate feature Foundation_NSString only.
source

pub unsafe fn decodeSizeForKey(&self, key: &NSString) -> NSSize

Available on crate feature Foundation_NSString only.
source

pub unsafe fn decodeRectForKey(&self, key: &NSString) -> NSRect

Available on crate feature Foundation_NSString only.

Methods from Deref<Target = AnyObject>

source

pub fn class(&self) -> &AnyClass

Dynamically find the class of this object.

source

pub unsafe fn ivar_ptr<T>(&self, name: &str) -> *mut Twhere T: Encode,

Returns a pointer to the instance variable / ivar with the given name.

This is similar to UnsafeCell::get, see that for more information on what is and isn’t safe to do.

Usually you will have defined the instance variable yourself with ClassBuilder::add_ivar, the type of the ivar T must match the type used in that.

Attempting to access or modify private implementation details of a class that you do no control using this is not supported, and may invoke undefined behaviour.

Library implementors are strongly encouraged to expose a safe interface to the ivar.

Panics

May panic if the object has no ivar with the given name. May also panic if the type encoding of the ivar differs from the type encoding of T.

This should purely seen as help while debugging and is not guaranteed (e.g. it may be disabled when debug_assertions are off).

Safety

The object must have an instance variable with the given name, and it must be of type T. Any invariants that the object have assumed about the value of the instance variable must not be violated.

No thread syncronization is done on accesses to the variable, so you must ensure that any access to the returned pointer do not cause data races, and that Rust’s mutability rules are not otherwise violated.

source

pub unsafe fn ivar<T>(&self, name: &str) -> &Twhere T: Encode,

Returns a reference to the instance variable with the given name.

See AnyObject::ivar_ptr for more information, including on when this panics.

Safety

The object must have an instance variable with the given name, and it must be of type T.

No thread syncronization is done, so you must ensure that no other thread is concurrently mutating the variable. This requirement can be considered upheld if all mutation happens through AnyObject::ivar_mut (since that takes &mut self).

source

pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere T: Encode,

👎Deprecated: Use AnyObject::ivar instead.
source

pub unsafe fn ivar_mut<T>(&mut self, name: &str) -> &mut Twhere T: Encode,

Returns a mutable reference to the ivar with the given name.

See AnyObject::ivar_ptr for more information, including on when this panics.

Safety

The object must have an instance variable with the given name, and it must be of type T.

This access happens through &mut self, which means we know it to be the only reference, hence you do not need to do any work to ensure that data races do not happen.

source

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere T: Encode,

👎Deprecated: Use AnyObject::ivar_mut instead.
source

pub unsafe fn set_ivar<T>(&mut self, name: &str, value: T)where T: Encode,

Sets the value of the ivar with the given name.

This is a shorthand for AnyObject::ivar_mut, see that for more information.

Safety

Same as AnyObject::ivar_mut.