Struct icrate::Foundation::NSMutableArray
source · #[repr(C)]pub struct NSMutableArray<ObjectType: Message = AnyObject> { /* private fields */ }Foundation and Foundation_NSArray only.Implementations
sourceimpl<T: Message> NSMutableArray<T>
impl<T: Message> NSMutableArray<T>
pub fn from_vec(vec: Vec<Id<T>>) -> Id<Self>
Foundation_NSMutableArray only.pub fn from_id_slice(slice: &[Id<T>]) -> Id<Self>where T: IsIdCloneable,
Foundation_NSMutableArray only.pub fn from_slice(slice: &[&T]) -> Id<Self>where T: IsRetainable,
Foundation_NSMutableArray only.pub fn into_vec(array: Id<Self>) -> Vec<Id<T>>
Foundation_NSMutableArray only.sourceimpl<T: Message> NSMutableArray<T>
impl<T: Message> NSMutableArray<T>
pub fn push(&mut self, obj: Id<T>)
Foundation_NSMutableArray only.pub fn insert(&mut self, index: usize, obj: Id<T>)
Foundation_NSMutableArray only.pub fn replace(&mut self, index: usize, obj: Id<T>) -> Result<Id<T>, Id<T>>
Foundation_NSMutableArray only.pub fn remove(&mut self, index: usize) -> Option<Id<T>>
Foundation_NSMutableArray only.pub fn pop(&mut self) -> Option<Id<T>>
Foundation_NSMutableArray only.pub fn sort_by<F: FnMut(&T, &T) -> Ordering>(&mut self, compare: F)
Foundation_NSMutableArray only.sourceimpl<ObjectType: Message> NSMutableArray<ObjectType>
impl<ObjectType: Message> NSMutableArray<ObjectType>
Methods declared on superclass NSArray
NSArrayCreation
pub unsafe fn array() -> Id<Self>
Foundation_NSMutableArray only.pub unsafe fn arrayWithObject(an_object: &ObjectType) -> Id<Self>
Foundation_NSMutableArray only.pub unsafe fn arrayWithObjects_count( objects: NonNull<NonNull<ObjectType>>, cnt: NSUInteger ) -> Id<Self>
Foundation_NSMutableArray only.pub unsafe fn arrayWithArray(array: &NSArray<ObjectType>) -> Id<Self>
Foundation_NSMutableArray only.pub unsafe fn initWithArray( this: Option<Allocated<Self>>, array: &NSArray<ObjectType> ) -> Id<Self>
Foundation_NSMutableArray only.pub unsafe fn initWithArray_copyItems( this: Option<Allocated<Self>>, array: &NSArray<ObjectType>, flag: bool ) -> Id<Self>
Foundation_NSMutableArray only.sourceimpl<ObjectType: Message> NSMutableArray<ObjectType>
impl<ObjectType: Message> NSMutableArray<ObjectType>
pub unsafe fn addObject(&mut self, an_object: &ObjectType)
Foundation_NSMutableArray only.pub unsafe fn insertObject_atIndex( &mut self, an_object: &ObjectType, index: NSUInteger )
Foundation_NSMutableArray only.pub unsafe fn removeLastObject(&mut self)
Foundation_NSMutableArray only.pub unsafe fn removeObjectAtIndex(&mut self, index: NSUInteger)
Foundation_NSMutableArray only.pub unsafe fn replaceObjectAtIndex_withObject( &mut self, index: NSUInteger, an_object: &ObjectType )
Foundation_NSMutableArray only.pub fn init(this: Option<Allocated<Self>>) -> Id<Self>
Foundation_NSMutableArray only.pub unsafe fn initWithCapacity( this: Option<Allocated<Self>>, num_items: NSUInteger ) -> Id<Self>
Foundation_NSMutableArray only.pub unsafe fn initWithCoder( this: Option<Allocated<Self>>, coder: &NSCoder ) -> Option<Id<Self>>
Foundation_NSMutableArray and Foundation_NSCoder only.sourceimpl<ObjectType: Message> NSMutableArray<ObjectType>
impl<ObjectType: Message> NSMutableArray<ObjectType>
Methods declared on superclass NSArray
pub unsafe fn initWithObjects_count( this: Option<Allocated<Self>>, objects: *mut NonNull<ObjectType>, cnt: NSUInteger ) -> Id<Self>
Foundation_NSMutableArray only.sourceimpl<ObjectType: Message> NSMutableArray<ObjectType>
impl<ObjectType: Message> NSMutableArray<ObjectType>
Methods declared on superclass NSObject
sourceimpl<ObjectType: Message> NSMutableArray<ObjectType>
impl<ObjectType: Message> NSMutableArray<ObjectType>
NSExtendedMutableArray
pub unsafe fn addObjectsFromArray(&mut self, other_array: &NSArray<ObjectType>)
Foundation_NSMutableArray only.pub unsafe fn exchangeObjectAtIndex_withObjectAtIndex( &mut self, idx1: NSUInteger, idx2: NSUInteger )
Foundation_NSMutableArray only.pub fn removeAllObjects(&mut self)
Foundation_NSMutableArray only.pub unsafe fn removeObject_inRange( &mut self, an_object: &ObjectType, range: NSRange )
Foundation_NSMutableArray only.pub unsafe fn removeObject(&mut self, an_object: &ObjectType)
Foundation_NSMutableArray only.pub unsafe fn removeObjectIdenticalTo_inRange( &mut self, an_object: &ObjectType, range: NSRange )
Foundation_NSMutableArray only.pub unsafe fn removeObjectIdenticalTo(&mut self, an_object: &ObjectType)
Foundation_NSMutableArray only.pub unsafe fn removeObjectsFromIndices_numIndices( &mut self, indices: NonNull<NSUInteger>, cnt: NSUInteger )
Foundation_NSMutableArray only.pub unsafe fn removeObjectsInArray(&mut self, other_array: &NSArray<ObjectType>)
Foundation_NSMutableArray only.pub unsafe fn removeObjectsInRange(&mut self, range: NSRange)
Foundation_NSMutableArray only.pub unsafe fn replaceObjectsInRange_withObjectsFromArray_range( &mut self, range: NSRange, other_array: &NSArray<ObjectType>, other_range: NSRange )
Foundation_NSMutableArray only.pub unsafe fn replaceObjectsInRange_withObjectsFromArray( &mut self, range: NSRange, other_array: &NSArray<ObjectType> )
Foundation_NSMutableArray only.pub unsafe fn setArray(&mut self, other_array: &NSArray<ObjectType>)
Foundation_NSMutableArray only.pub unsafe fn sortUsingFunction_context( &mut self, compare: unsafe extern "C" fn(_: NonNull<ObjectType>, _: NonNull<ObjectType>, _: *mut c_void) -> NSInteger, context: *mut c_void )
Foundation_NSMutableArray only.pub unsafe fn sortUsingSelector(&mut self, comparator: Sel)
Foundation_NSMutableArray only.pub unsafe fn insertObjects_atIndexes( &mut self, objects: &NSArray<ObjectType>, indexes: &NSIndexSet )
Foundation_NSMutableArray and Foundation_NSIndexSet only.pub unsafe fn removeObjectsAtIndexes(&mut self, indexes: &NSIndexSet)
Foundation_NSMutableArray and Foundation_NSIndexSet only.pub unsafe fn replaceObjectsAtIndexes_withObjects( &mut self, indexes: &NSIndexSet, objects: &NSArray<ObjectType> )
Foundation_NSMutableArray and Foundation_NSIndexSet only.pub unsafe fn setObject_atIndexedSubscript( &mut self, obj: &ObjectType, idx: NSUInteger )
Foundation_NSMutableArray only.pub unsafe fn sortUsingComparator(&mut self, cmptr: NSComparator)
Foundation_NSMutableArray only.pub unsafe fn sortWithOptions_usingComparator( &mut self, opts: NSSortOptions, cmptr: NSComparator )
Foundation_NSMutableArray only.sourceimpl<ObjectType: Message> NSMutableArray<ObjectType>
impl<ObjectType: Message> NSMutableArray<ObjectType>
NSMutableArrayCreation
pub unsafe fn arrayWithCapacity(num_items: NSUInteger) -> Id<Self>
Foundation_NSMutableArray only.pub unsafe fn arrayWithContentsOfFile( path: &NSString ) -> Option<Id<NSMutableArray<ObjectType>>>
Foundation_NSMutableArray and Foundation_NSString only.pub unsafe fn arrayWithContentsOfURL( url: &NSURL ) -> Option<Id<NSMutableArray<ObjectType>>>
Foundation_NSMutableArray and Foundation_NSURL only.pub unsafe fn initWithContentsOfFile( this: Option<Allocated<Self>>, path: &NSString ) -> Option<Id<NSMutableArray<ObjectType>>>
Foundation_NSMutableArray and Foundation_NSString only.pub unsafe fn initWithContentsOfURL( this: Option<Allocated<Self>>, url: &NSURL ) -> Option<Id<NSMutableArray<ObjectType>>>
Foundation_NSMutableArray and Foundation_NSURL only.sourceimpl<ObjectType: Message> NSMutableArray<ObjectType>
impl<ObjectType: Message> NSMutableArray<ObjectType>
NSMutableArrayDiffing
pub unsafe fn applyDifference( &mut self, difference: &NSOrderedCollectionDifference<ObjectType> )
Foundation_NSMutableArray and Foundation_NSOrderedCollectionDifference only.sourceimpl<ObjectType: Message> NSMutableArray<ObjectType>
impl<ObjectType: Message> NSMutableArray<ObjectType>
NSPredicateSupport
pub unsafe fn filterUsingPredicate(&mut self, predicate: &NSPredicate)
Foundation_NSMutableArray and Foundation_NSPredicate only.sourceimpl<ObjectType: Message> NSMutableArray<ObjectType>
impl<ObjectType: Message> NSMutableArray<ObjectType>
NSSortDescriptorSorting
pub unsafe fn sortUsingDescriptors( &mut self, sort_descriptors: &NSArray<NSSortDescriptor> )
Foundation_NSMutableArray and Foundation_NSSortDescriptor only.Methods from Deref<Target = NSArray<ObjectType>>
pub fn to_vec(&self) -> Vec<&T>
pub fn to_vec_retained(&self) -> Vec<Id<T>>where T: IsIdCloneable,
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn get(&self, index: usize) -> Option<&T>
pub fn get_retained(&self, index: usize) -> Option<Id<T>>where T: IsIdCloneable,
pub fn get_mut(&mut self, index: usize) -> Option<&mut T>where T: IsMutable,
pub fn first(&self) -> Option<&T>
pub fn first_retained(&self) -> Option<Id<T>>where T: IsIdCloneable,
pub fn first_mut(&mut self) -> Option<&mut T>where T: IsMutable,
pub fn last(&self) -> Option<&T>
pub fn last_retained(&self) -> Option<Id<T>>where T: IsIdCloneable,
pub fn last_mut(&mut self) -> Option<&mut T>where T: IsMutable,
pub fn objects_in_range(&self, range: Range<usize>) -> Option<Vec<&T>>
pub fn iter(&self) -> Iter<'_, T> ⓘ
pub fn iter_mut(&mut self) -> IterMut<'_, T> ⓘwhere T: IsMutable,
pub fn iter_retained(&self) -> IterRetained<'_, T> ⓘwhere T: IsIdCloneable,
pub fn count(&self) -> NSUInteger
pub unsafe fn objectAtIndex(&self, index: NSUInteger) -> Id<ObjectType>
pub unsafe fn arrayByAddingObject( &self, an_object: &ObjectType ) -> Id<NSArray<ObjectType>>
pub unsafe fn arrayByAddingObjectsFromArray( &self, other_array: &NSArray<ObjectType> ) -> Id<NSArray<ObjectType>>
pub unsafe fn componentsJoinedByString( &self, separator: &NSString ) -> Id<NSString>
Foundation_NSString only.pub unsafe fn containsObject(&self, an_object: &ObjectType) -> bool
pub unsafe fn description(&self) -> Id<NSString>
Foundation_NSString only.pub unsafe fn descriptionWithLocale( &self, locale: Option<&AnyObject> ) -> Id<NSString>
Foundation_NSString only.pub unsafe fn descriptionWithLocale_indent( &self, locale: Option<&AnyObject>, level: NSUInteger ) -> Id<NSString>
Foundation_NSString only.pub unsafe fn firstObjectCommonWithArray( &self, other_array: &NSArray<ObjectType> ) -> Option<Id<ObjectType>>
pub unsafe fn getObjects_range( &self, objects: NonNull<NonNull<ObjectType>>, range: NSRange )
pub unsafe fn indexOfObject(&self, an_object: &ObjectType) -> NSUInteger
pub unsafe fn indexOfObject_inRange( &self, an_object: &ObjectType, range: NSRange ) -> NSUInteger
pub unsafe fn indexOfObjectIdenticalTo( &self, an_object: &ObjectType ) -> NSUInteger
pub unsafe fn indexOfObjectIdenticalTo_inRange( &self, an_object: &ObjectType, range: NSRange ) -> NSUInteger
pub unsafe fn isEqualToArray(&self, other_array: &NSArray<ObjectType>) -> bool
pub unsafe fn firstObject(&self) -> Option<Id<ObjectType>>
pub unsafe fn lastObject(&self) -> Option<Id<ObjectType>>
pub unsafe fn objectEnumerator(&self) -> Id<NSEnumerator<ObjectType>>
Foundation_NSEnumerator only.pub unsafe fn reverseObjectEnumerator(&self) -> Id<NSEnumerator<ObjectType>>
Foundation_NSEnumerator only.pub unsafe fn sortedArrayHint(&self) -> Id<NSData>
Foundation_NSData only.pub unsafe fn sortedArrayUsingFunction_context( &self, comparator: unsafe extern "C" fn(_: NonNull<ObjectType>, _: NonNull<ObjectType>, _: *mut c_void) -> NSInteger, context: *mut c_void ) -> Id<NSArray<ObjectType>>
pub unsafe fn sortedArrayUsingFunction_context_hint( &self, comparator: unsafe extern "C" fn(_: NonNull<ObjectType>, _: NonNull<ObjectType>, _: *mut c_void) -> NSInteger, context: *mut c_void, hint: Option<&NSData> ) -> Id<NSArray<ObjectType>>
Foundation_NSData only.pub unsafe fn sortedArrayUsingSelector( &self, comparator: Sel ) -> Id<NSArray<ObjectType>>
pub unsafe fn subarrayWithRange( &self, range: NSRange ) -> Id<NSArray<ObjectType>>
pub unsafe fn writeToURL_error(&self, url: &NSURL) -> Result<(), Id<NSError>>
Foundation_NSError and Foundation_NSURL only.pub unsafe fn makeObjectsPerformSelector(&self, a_selector: Sel)
pub unsafe fn makeObjectsPerformSelector_withObject( &self, a_selector: Sel, argument: Option<&AnyObject> )
pub unsafe fn objectsAtIndexes( &self, indexes: &NSIndexSet ) -> Id<NSArray<ObjectType>>
Foundation_NSIndexSet only.pub unsafe fn objectAtIndexedSubscript(&self, idx: NSUInteger) -> Id<ObjectType>
pub unsafe fn enumerateObjectsUsingBlock( &self, block: &Block<(NonNull<ObjectType>, NSUInteger, NonNull<Bool>), ()> )
pub unsafe fn enumerateObjectsWithOptions_usingBlock( &self, opts: NSEnumerationOptions, block: &Block<(NonNull<ObjectType>, NSUInteger, NonNull<Bool>), ()> )
pub unsafe fn enumerateObjectsAtIndexes_options_usingBlock( &self, s: &NSIndexSet, opts: NSEnumerationOptions, block: &Block<(NonNull<ObjectType>, NSUInteger, NonNull<Bool>), ()> )
Foundation_NSIndexSet only.pub unsafe fn indexOfObjectPassingTest( &self, predicate: &Block<(NonNull<ObjectType>, NSUInteger, NonNull<Bool>), Bool> ) -> NSUInteger
pub unsafe fn indexOfObjectWithOptions_passingTest( &self, opts: NSEnumerationOptions, predicate: &Block<(NonNull<ObjectType>, NSUInteger, NonNull<Bool>), Bool> ) -> NSUInteger
pub unsafe fn indexOfObjectAtIndexes_options_passingTest( &self, s: &NSIndexSet, opts: NSEnumerationOptions, predicate: &Block<(NonNull<ObjectType>, NSUInteger, NonNull<Bool>), Bool> ) -> NSUInteger
Foundation_NSIndexSet only.pub unsafe fn indexesOfObjectsPassingTest( &self, predicate: &Block<(NonNull<ObjectType>, NSUInteger, NonNull<Bool>), Bool> ) -> Id<NSIndexSet>
Foundation_NSIndexSet only.pub unsafe fn indexesOfObjectsWithOptions_passingTest( &self, opts: NSEnumerationOptions, predicate: &Block<(NonNull<ObjectType>, NSUInteger, NonNull<Bool>), Bool> ) -> Id<NSIndexSet>
Foundation_NSIndexSet only.pub unsafe fn indexesOfObjectsAtIndexes_options_passingTest( &self, s: &NSIndexSet, opts: NSEnumerationOptions, predicate: &Block<(NonNull<ObjectType>, NSUInteger, NonNull<Bool>), Bool> ) -> Id<NSIndexSet>
Foundation_NSIndexSet only.pub unsafe fn sortedArrayUsingComparator( &self, cmptr: NSComparator ) -> Id<NSArray<ObjectType>>
pub unsafe fn sortedArrayWithOptions_usingComparator( &self, opts: NSSortOptions, cmptr: NSComparator ) -> Id<NSArray<ObjectType>>
pub unsafe fn indexOfObject_inSortedRange_options_usingComparator( &self, obj: &ObjectType, r: NSRange, opts: NSBinarySearchingOptions, cmp: NSComparator ) -> NSUInteger
pub unsafe fn differenceFromArray_withOptions_usingEquivalenceTest( &self, other: &NSArray<ObjectType>, options: NSOrderedCollectionDifferenceCalculationOptions, block: &Block<(NonNull<ObjectType>, NonNull<ObjectType>), Bool> ) -> Id<NSOrderedCollectionDifference<ObjectType>>
Foundation_NSOrderedCollectionDifference only.pub unsafe fn differenceFromArray_withOptions( &self, other: &NSArray<ObjectType>, options: NSOrderedCollectionDifferenceCalculationOptions ) -> Id<NSOrderedCollectionDifference<ObjectType>>
Foundation_NSOrderedCollectionDifference only.pub unsafe fn differenceFromArray( &self, other: &NSArray<ObjectType> ) -> Id<NSOrderedCollectionDifference<ObjectType>>
Foundation_NSOrderedCollectionDifference only.pub unsafe fn arrayByApplyingDifference( &self, difference: &NSOrderedCollectionDifference<ObjectType> ) -> Option<Id<NSArray<ObjectType>>>
Foundation_NSOrderedCollectionDifference only.pub unsafe fn getObjects(&self, objects: NonNull<NonNull<ObjectType>>)
pub unsafe fn writeToFile_atomically( &self, path: &NSString, use_auxiliary_file: bool ) -> bool
Foundation_NSString only.pub unsafe fn writeToURL_atomically( &self, url: &NSURL, atomically: bool ) -> bool
Foundation_NSURL only.pub unsafe fn valueForKey(&self, key: &NSString) -> Id<AnyObject>
Foundation_NSString only.pub unsafe fn setValue_forKey(&self, value: Option<&AnyObject>, key: &NSString)
Foundation_NSString only.pub unsafe fn addObserver_toObjectsAtIndexes_forKeyPath_options_context( &self, observer: &NSObject, indexes: &NSIndexSet, key_path: &NSString, options: NSKeyValueObservingOptions, context: *mut c_void )
Foundation_NSIndexSet and Foundation_NSString only.pub unsafe fn removeObserver_fromObjectsAtIndexes_forKeyPath_context( &self, observer: &NSObject, indexes: &NSIndexSet, key_path: &NSString, context: *mut c_void )
Foundation_NSIndexSet and Foundation_NSString only.pub unsafe fn removeObserver_fromObjectsAtIndexes_forKeyPath( &self, observer: &NSObject, indexes: &NSIndexSet, key_path: &NSString )
Foundation_NSIndexSet and Foundation_NSString only.pub unsafe fn addObserver_forKeyPath_options_context( &self, observer: &NSObject, key_path: &NSString, options: NSKeyValueObservingOptions, context: *mut c_void )
Foundation_NSString only.pub unsafe fn removeObserver_forKeyPath_context( &self, observer: &NSObject, key_path: &NSString, context: *mut c_void )
Foundation_NSString only.pub unsafe fn removeObserver_forKeyPath( &self, observer: &NSObject, key_path: &NSString )
Foundation_NSString only.pub unsafe fn pathsMatchingExtensions( &self, filter_types: &NSArray<NSString> ) -> Id<NSArray<NSString>>
Foundation_NSString only.pub unsafe fn filteredArrayUsingPredicate( &self, predicate: &NSPredicate ) -> Id<NSArray<ObjectType>>
Foundation_NSPredicate only.pub unsafe fn sortedArrayUsingDescriptors( &self, sort_descriptors: &NSArray<NSSortDescriptor> ) -> Id<NSArray<ObjectType>>
Foundation_NSSortDescriptor only.Methods from Deref<Target = AnyObject>
sourcepub unsafe fn ivar_ptr<T>(&self, name: &str) -> *mut Twhere
T: Encode,
pub unsafe fn ivar_ptr<T>(&self, name: &str) -> *mut Twhere T: Encode,
Returns a pointer to the instance variable / ivar with the given name.
This is similar to UnsafeCell::get, see that for more information
on what is and isn’t safe to do.
Usually you will have defined the instance variable yourself with
ClassBuilder::add_ivar, the type of the ivar T must match the
type used in that.
Attempting to access or modify private implementation details of a class that you do no control using this is not supported, and may invoke undefined behaviour.
Library implementors are strongly encouraged to expose a safe interface to the ivar.
Panics
May panic if the object has no ivar with the given name. May also
panic if the type encoding of the ivar differs from the type encoding
of T.
This should purely seen as help while debugging and is not guaranteed
(e.g. it may be disabled when debug_assertions are off).
Safety
The object must have an instance variable with the given name, and it
must be of type T. Any invariants that the object have assumed about
the value of the instance variable must not be violated.
No thread syncronization is done on accesses to the variable, so you must ensure that any access to the returned pointer do not cause data races, and that Rust’s mutability rules are not otherwise violated.
sourcepub unsafe fn ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
pub unsafe fn ivar<T>(&self, name: &str) -> &Twhere T: Encode,
Returns a reference to the instance variable with the given name.
See AnyObject::ivar_ptr for more information, including on when
this panics.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
No thread syncronization is done, so you must ensure that no other
thread is concurrently mutating the variable. This requirement can be
considered upheld if all mutation happens through
AnyObject::ivar_mut (since that takes &mut self).
sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: Use AnyObject::ivar instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere T: Encode,
AnyObject::ivar instead.sourcepub unsafe fn ivar_mut<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
pub unsafe fn ivar_mut<T>(&mut self, name: &str) -> &mut Twhere T: Encode,
Returns a mutable reference to the ivar with the given name.
See AnyObject::ivar_ptr for more information, including on when
this panics.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
This access happens through &mut self, which means we know it to be
the only reference, hence you do not need to do any work to ensure
that data races do not happen.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: Use AnyObject::ivar_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere T: Encode,
AnyObject::ivar_mut instead.sourcepub unsafe fn set_ivar<T>(&mut self, name: &str, value: T)where
T: Encode,
pub unsafe fn set_ivar<T>(&mut self, name: &str, value: T)where T: Encode,
Sets the value of the ivar with the given name.
This is a shorthand for AnyObject::ivar_mut, see that for more
information.
Safety
Same as AnyObject::ivar_mut.